#
# spec file for package gnome-session
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-session
Version:        3.26.1
Release:        lp150.4.2
Summary:        Session Tools for the GNOME Desktop
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
Url:            http://www.gnome.org
Source:         http://download.gnome.org/sources/gnome-session/3.26/%{name}-%{version}.tar.xz
Source1:        gnome
Source2:        gnome.desktop
# PATCH-FEATURE-UPSTREAM gnome-session-logging-to-systemd-journal-configurable.patch bsc#876685 bgo#768982 fezhang@suse.com -- Add a new configure switch for systemd journal support.
Patch0:         gnome-session-logging-to-systemd-journal-configurable.patch
# PATCH-FIX-UPSTREAM gnome-session-nb-translation.patch zaitor@opensuse.org -- Update Norwegian bokmål translations
Patch1:         gnome-session-nb-translation.patch
# PATCH-FIX-UPSTREAM gnome-session-better-handle-empty-xdg_session_type.patch bsc#1084756 bgo#794256 yfjiang@suse.com -- solution provided by msrb@suse.com using a more reasonable way to handle gpu acceleration check
Patch2:         gnome-session-better-handle-empty-xdg_session_type.patch
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  tcpd-devel
BuildRequires:  update-desktop-files
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.76
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.35.0
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glib-2.0) >= 2.35.0
BuildRequires:  pkgconfig(gnome-desktop-3.0) >= 3.9.91
BuildRequires:  pkgconfig(gtk+-3.0) >= 2.90.7
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.10
BuildRequires:  pkgconfig(libsystemd) >= 209
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xtrans)
BuildRequires:  pkgconfig(xtst)
Requires:       %{name}-core = %{version}
Requires:       %{name}-default-session = %{version}
Recommends:     %{name}-lang
%if !0%{?is_opensuse}
BuildRequires:  translation-update-upstream
%endif
# gnome-session-wayland not recommended by default yet: causes various issues:
# qemu's default video mode is 'cirrus', which stays black with GNOME Wayland
# YaST cannot be started without additional tricks
# All together this blocks us from passing openQA
# Recommends:     %%{name}-wayland

%description
This package provides the basic session tools, like session management
functionality, for the GNOME Desktop.

%package default-session
Summary:        Default session support for the GNOME Session Manager
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Requires:       gnome-settings-daemon
Requires:       gnome-shell

%description default-session
This package contains the definition of the default GNOME session.

%package wayland
Summary:        Wayland support for the GNOME Session Manager
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Requires:       gnome-settings-daemon
Requires:       xorg-x11-server-wayland

%description wayland
This package contains the definition of the default GNOME session on Wayland.

%package core
Summary:        Minimal version of the GNOME Session Manager
Group:          System/GUI/GNOME
Requires:       dbus-1-x11
Requires:       gsettings-desktop-schemas >= 0.1.7
Requires:       hicolor-icon-theme
%glib2_gsettings_schema_requires

%description core
This package contains a minimal version of gnome-session, that can be
used for specific cases. The gnome-session package is needed for a fully
functional GNOME desktop.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%if !0%{?is_opensuse}
translation-update-upstream
%endif

%build
%configure \
        --enable-systemd \
%if !0%{?is_opensuse}
        --disable-systemd-journal \
%endif
        --disable-gconf
make %{?_smp_mflags}

%install
%make_install
# install startup script and xsession file
install -d -m755 %{buildroot}%{_bindir}
install -m755 %{SOURCE1} %{buildroot}%{_bindir}/gnome
install -d -m755 %{buildroot}%{_datadir}/xsessions
install -m644 %{SOURCE2} %{buildroot}%{_datadir}/xsessions/gnome.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/gnome.desktop
%find_lang %{name}-3.0 %{?no_lang_C}
%fdupes %{buildroot}/%{_prefix}
# remove wayland files on s390/s390x
%ifarch s390 s390x
rm -fr %{buildroot}%{_datadir}/wayland-sessions
%endif

# Prepare for 'default.desktop' being update-alternative handled, boo#1039756
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop
%ifnarch s390 s390x
touch %{buildroot}%{_sysconfdir}/alternatives/default-waylandsession.desktop
ln -s %{_sysconfdir}/alternatives/default-waylandsession.desktop %{buildroot}%{_datadir}/wayland-sessions/default.desktop
%endif

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/gnome.desktop 25

%postun
[ -f %{_datadir}/xsessions/gnome.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/gnome.desktop

%files
%{_bindir}/gnome
%{_datadir}/xsessions/default.desktop
%{_datadir}/xsessions/gnome.desktop
%{_datadir}/xsessions/gnome-xorg.desktop
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop

%files default-session
%{_datadir}/gnome-session/sessions/gnome.session
%{_datadir}/gnome-session/sessions/gnome-dummy.session

%ifnarch s390 s390x
%post wayland
%{_sbindir}/update-alternatives --install %{_datadir}/wayland-sessions/default.desktop \
  default-waylandsession.desktop %{_datadir}/wayland-sessions/gnome.desktop 25

%postun wayland
[ -f %{_datadir}/wayland-sessions/gnome.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-waylandsession.desktop %{_datadir}/wayland-sessions/gnome.desktop

%files wayland
%dir %{_datadir}/wayland-sessions
%{_datadir}/wayland-sessions/default.desktop
%{_datadir}/wayland-sessions/gnome.desktop
%ghost %{_sysconfdir}/alternatives/default-waylandsession.desktop
# Disabled as wayland is now the default session again.
#{_datadir}/wayland-sessions/gnome-wayland.desktop
%endif

%files core
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/gnome-session
%{_bindir}/gnome-session-inhibit
%{_bindir}/gnome-session-quit
%{_datadir}/GConf/gsettings/gnome-session.convert
%{_datadir}/glib-2.0/schemas/org.gnome.SessionManager.gschema.xml
%dir %{_datadir}/gnome-session
%dir %{_datadir}/gnome-session/sessions
%{_mandir}/man1/gnome-session.1%{?ext_man}
%{_mandir}/man1/gnome-session-inhibit.1%{?ext_man}
%{_mandir}/man1/gnome-session-quit.1%{?ext_man}
%{_libexecdir}/gnome-session-binary
# Helper for the session definitions, to know if hardware is accelerated
%{_libexecdir}/gnome-session-check-accelerated
%{_libexecdir}/gnome-session-check-accelerated-gl-helper
%{_libexecdir}/gnome-session-check-accelerated-gles-helper
%{_libexecdir}/gnome-session-failed
%{_datadir}/gnome-session/hardware-compatibility

%files lang -f %{name}-3.0.lang

%changelog
* Wed Mar 14 2018 yfjiang@suse.com
- Add gnome-session-better-handle-empty-xdg_session_type.patch
  The gnome-session-check-accelerated currently detects wayland
  by checking if XDG_SESSION_TYPE != "x11". More appropriate test
  would be XDG_SESSION_TYPE == "wayland".
  This is especially important for cases when XDG_SESSION_TYPE is
  not set to anything at all - in such case it is more likely
  that the intention is to run gnome inside X11 (bsc#1084756,
  bgo#794256).
  The analysis and the patch is fully provided by msrb@suse.com.
* Mon Feb 26 2018 ro@suse.de
- Fix build on s390/s390x without wayland: do not setup the system
  for default-waylandsession alternatives.
* Sun Dec 24 2017 zaitor@opensuse.org
- Add gnome-session-nb-translation.patch: Update Norwegian bokmål
  translations.
* Thu Oct 19 2017 xwang@suse.com
- Make default.desktop session working on wayland.
  Add default.desktop file in '{_datadir}/wayland-sessions/'
  (bsc#1062196).
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Log warning fix.
  + Updated translations.
* Fri Sep 22 2017 fcrozat@suse.com
- Re-add
  gnome-session-logging-to-systemd-journal-configurable.patch (not
  yet upstream [bsc#979498], [bgo#768982]).
* Fri Sep 22 2017 dimstar@opensuse.org
- Revert "Enable SLE-Classic for wayland": the SLE-Classic session
  requires gnome-shell-extensions, which is the reason why the
  X-Session is shipped as part of that package. The wayland session
  should also be there.
* Wed Sep 20 2017 dimstar@opensuse.org
- Register GNOME with u-a handler for default.desktop
  implementation, which obsoletes the change in
  /etc/sysconfig/windowmanager to pick the 'default window manager'
  (boo#1039756).
* Fri Sep 15 2017 xwang@suse.com
- Enable SLE-Classic session working on Wayland.
  Add sle-classic.desktop in folder '{_datadir}/wayland-sessions/'
  (bsc#1058797)
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Updated translations.
* Sat Sep  9 2017 jengelh@inai.de
- Update package summaries.
  Drop an idempotent %%if..%%endif block around %%package declaration.
- Avoid running fdupes across hardlink boundaries.
* Fri Sep  8 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + gnome-session-inhibit fix.
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Updated translations.
* Mon Jul 24 2017 fcrozat@suse.com
- Do not build wayland subpackage on s390/s390x, xwayland doesn't
  exist there [bsc#1047173].
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Restart dbus-daemon instead of killing dbus clients at log out.
  + Session file updates for latest g-s-d.
  + Misc memory fixes.
  + Updated translations.
* Mon Jul 10 2017 zaitor@opensuse.org
- Update to version 3.25.3:
  + Improved error messages with systemd integration.
  + Fix crash in fail whale if X dies.
  + Fix warning/crash when iterating over extensions.
  + Kill dbus clients at logout.
  + Leverage unicode for clarity and aesthetics.
  + BSD support improvements.
  + Drop old SSH_AUTH_SOCK on wayland workaround.
  + Updated translations.
- Drop post(un) handling for gnome-session and gnome-session-core,
  no longer needed as file-triggers now takes care of this.
* Sat Apr 15 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Autogoo degooing.
  + Race condition fix with startup and owning the dbus name.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + No changes.
* Mon Mar 13 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Updated translations.
* Tue Feb 28 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Fix VT monitor to work with restrictive SELinux policies.
  + Disable extensions in a less destructive way from fail whale.
  + Add support for absolute paths to AutostartCondition.
  + Updated translations.
- Drop gnome-session-Restrict-the-login-monitor.patch: Fixed
  upstream.
* Fri Feb 17 2017 dimstar@opensuse.org
- Update to version 3.23.4.1:
  + Redo login shell for wayland handling to be more functional and
    crossplatform.
* Fri Feb 17 2017 dimstar@opensuse.org
- Update to version 3.23.4:
  + Fix warnings at startup in check accelerated helper.
  + Print the renderer under wayland in check accelerated helper.
  + Fix gpu info caching logic.
  + Better error checking.
  + Don't tell Qt applications to look like GNOME anymore.
  + Make sure a login shell runs for wayland sessions at startup.
- Changes from version 3.23.3:
  + Update session desktop files for gnome-settings-daemon changes,
    the big daemon is now split up into smaller daemons.
  + Updated translations.
* Thu Feb 16 2017 dimstar@opensuse.org
- Do not try to bootstrap on SLE neither: there are no patches
  applied.
* Wed Feb 15 2017 zaitor@opensuse.org
- Add gnome-session-Restrict-the-login-monitor.patch: Restrict the
  login monitor to the "session" category. This reduces overhead
  by a small amount, and also reduces the amount of
  /var/run/systemd that needs to be read.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Misc fixes to gnome-session-check-accelerated.
  + Updated translations.
- Add pkgconfig(epoxy) BuildRequires: new verified dependency.
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Fix problem when cancelling the power off dialogue.
  + Don't set locale information again after the localeexec wrapper
    already does.
  + Drop gnome-session-bsc979257-bgo728151-duplicated-poweroff-dialog.patch
    Fixed upstream.
* Thu Sep 29 2016 federico@suse.com
- Added gnome-session-bsc979257-bgo728151-duplicated-poweroff-dialog.patch
  for bsc#979257.  Pressing Ctrl-Alt-Del would open a Power Off
  dialog, but in order to cancel it one needed to press Cancel
  twice.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Small fix for dash users.
  + Updated translations.
* Wed Sep 14 2016 dimstar@opensuse.org
- Do not recommend gnome-session-wayland for now. There are still
  a couple issues to solve:
  + openQA uses the cirrus video driver (qemu's default) which does
    not work with Wayland (we can potentially switch that to qxl
    for GNOME tests).
  + YaST still needs extra tricks to start (root has no direct
    access to Xwayland.
* Thu Aug 18 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Do not report errors in the absence of
    dbus-update-activation-environment.
  + Support reading kernel gnome.fallback variable on FreeBSD.
  + Allow IM environment variables to be overridden.
  + Updated translations.
- Drop gnome-session-ice-auth-for-suid.patch: Patch decleared
  obsolete by author.
- Drop gnome-session-check-dbus-update-activation-environment.patch
  and gnome-session-logging-to-systemd-journal-configurable.patch:
  Fixed upstream.
- Following the above: Drop autoconf BuildRequires and stop passing
  of it.
- Stop passing V=1 to makeinstall, debugging is local.
* Thu Aug 18 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Export renderer string for llvmpipe.
  + Small heap overflow fix.
  + Compiler warning fixes-
  + Misc doc fixes.
  + Futureproof gettext support.
* Thu Aug 18 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Updated translations.
* Thu Aug 18 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Switch back to wayland by default.
  + Update bus activation environment at startup.
  + Updated translations.
- Add pkgconfig(egl) and pkgconfig(glesv2) BuildRequires: New
  dependencies.
- Add gnome-session-wayland Recommends to gnome-session main
  package, we will now start gdm on wayland by default.
* Thu Aug 18 2016 dimstar@opensuse.org
- Update
  gnome-session-check-dbus-update-activation-environment.patch: use
  the upstream commited solution
* Tue Aug 16 2016 fezhang@suse.com
- Add gnome-session-check-dbus-update-activation-environment.patch:
  Check if dbus-update-activation-environment exists before calling
  it to silence warnings for SLE12 SP2 and LEAP 42.2 (bsc#993342,
  bgo#768036).
* Sun Jul 17 2016 fezhang@suse.com
- Add gnome-session-logging-to-systemd-journal-configurable.patch:
  Add an autoconf switch to control if the logs of gnome-session
  and its child processes should be sent to systemd journal or to
  the legacy ~/.xsession-errors-$DISPLAY when disabled (bsc#979498,
  bgo#768982).
- For SLE, disable logging to systemd journal: pass
  - -disable-systemd-journal to configure.
- Replace gnome-common BuildRequires with autoconf: this is
  sufficient to bootstrap gnome-session.
- Unconditionally call autoconf, as the newly added patch touches
  the build system.
- Drop gnome-session-disable-logging-to-systemd-journal.patch
  (bsc#979498). Function replaced by the more robust
  gnome-session-logging-to-systemd-journal-configurable.patch.
* Fri Jul 15 2016 alarrosa@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Mon Jul 11 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Fixes to D-Bus activation environment.
  + Compiler warning fixes.
  + Fail whale localization fix.
  + Fix heap corruption in dbus-launch wrapper code.
  + Updated translations.
* Wed Jul  6 2016 fbui@suse.com
- Replace pkgconfig(libsystemd-*) with pkgconfig(libsystemd)
  Nowadays pkgconfig(libsystemd) replaces all libsystemd-* libs,
  which are obsolete.
* Mon Jun 20 2016 fezhang@suse.com
- Revive gnome-session-disable-logging-to-systemd-journal.patch
  (bnc#979498) and also update it responding to the change
  introduced by upstream commit 5449174.
* Wed May 25 2016 zaitor@opensuse.org
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Change gnome-session-ice-auth-for-suid.patch patch tag to
  PATCH-FIX-SLE, and only apply for non-opensuse. Same for
  gnome-common BuildRequires and NOCONFIGURE call.
- Add xsltproc BuildRequries: Needed for man pages, pulled in by
  gnome-common before.
- Drop no longer needed Provides and Obsoletes: gnome-core,
  gnome-session-branding, gnome-session-gtk1-support,
  gnome-session-splash, gnome-session-fallback-session and
  gnome2-look-and-feel.
- Drop hicolor-icon-theme BuildRequires: We rely on Adwaita now,
  and that is always provided by gtk3.
* Fri May 20 2016 fezhang@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Wed Apr 13 2016 fezhang@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop gnome-session-commit-07852f0.patch: fixed upstream
- Drop gnome-session-pass-env-to-dbus.patch (bnc#869677):
  fixed upstream
- Drop gnome-session-remove-capplet.patch (bnc#863709, bgo#708923):
  fixed upstream
- Drop gnome-session-upower.patch: fixed upstream
- Drop gnome-session-disable-logging-to-systemd-journal.patch
  (bnc#876685): fixed upstream
* Tue Apr 12 2016 dimstar@opensuse.org
- Update to version 3.20.1:
  + Fix startx.
  + Updated translations.
- Drop main-fix-starting-gnome-session-via-startx.patch: fixed
  upstream.
* Thu Mar 31 2016 fcrozat@suse.com
- Add main-fix-starting-gnome-session-via-startx.patch: fix
  starting GNOME when using startx or old display managers
  (bgo#764379).
* Sat Mar 26 2016 zaitor@opensuse.org
- Add missing xorg-x11-server-wayland Requires for
  subpackage gnome-session-wayland.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Sat Mar 19 2016 zaitor@opensuse.org
- Stop pretending we still support a non systemd setup: Remove
  define with_systemd and conditional ConsoleKit Requires.
* Wed Mar 16 2016 zaitor@opensuse.org
- Update to version 3.19.92:
  + More logout fixes.
  + Switch back to Xorg by default.
  + Crasher fix.
  + Updated translations.
* Fri Mar  4 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Logout fixes.
  + Setup Qt to be themed right.
  + Use individual dbus watches instead of one one global
    NameOwnerChanged handler, to avoid spurious wake ups.
  + Updated translations.
* Thu Jan 21 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Give every app its own journal id.
  + Rework startup files as part of the wayland effort.
  + Fix command line help output.
- Drop gnome-session-gnome-shell-renamed.patch: fixed upstream.
- Drop gnome-session-autostart-app-give-every-app-journal-id.patch:
  fixed upstream.
* Mon Jan  4 2016 dimstar@opensuse.org
- Add gnome-session-gnome-shell-renamed.patch: gnome-shell.desktop
  has been renamed to org.gnome.Shell.desktop.
* Wed Dec 23 2015 dimstar@opensuse.org
- No longer require gnome-shell-wayland: the package no longer
  exists as the wayland session is being promoted to be default.
* Thu Nov 26 2015 zaitor@opensuse.org
- Add gnome-session-autostart-app-give-every-app-journal-id.patch:
  Give every app it's own journald-id. Patch from upstream.
* Mon Nov  9 2015 dimstar@opensuse.org
- Update gnome.desktop: add DesktopNames (upstream introduced in
  GNOME 3.12.1). Fixes boo#931314.
* Fri Oct 30 2015 zaitor@opensuse.org
- Drop pkgconfig(gconf-2.0) BuildRequires and pass --disable-gconf
  to configure to be sure it's not enabled during build. It was
  only present to support gconf-based autostart.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.18.1.2:
  + build-goo: generate shell script wrapper in different way
    (bgo#756633).
* Wed Oct 14 2015 zaitor@opensuse.org
- Update to version 3.18.1.1:
  + Fix typos in environment variable names.
* Wed Oct 14 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + No longer stash environment in
    $XDG_RUNTIME_DIR/gnome/environment.
  + Set SSH_AUTH_SOCK explicitly for wayland sessions.
  + Set LC environment variables up front, so g-s-d doesn't have to
    do it and hand it back to us later.
  + Set IBus environment variables too.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Bump version.
* Thu Sep 17 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Stash environment in $XDG_RUNTIME_DIR/gnome/environment.
  + Updated translations.
* Mon Mar 23 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + No changes from last version, stable bump.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Fix bug in tracking if the session is active.
  + Fail whale fixes.
  + Updated translations.
* Thu Feb 19 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Don't try to failwhale when the wayland compositor fails to
    start.
  + Support newer systemd client library layout.
  + Cut out more vestigial dbus-glib remnants.
  + Updated translations.
* Thu Jan 29 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Allow turning on debugging with an environment variable.
  + Don't set DISPLAY in wayland sessions.
  + Add back session-name property.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Port to GDBus.
  + Misc clean ups.
  + Updated translations.
- Pass --enable-systemd to configure to make sure we build with
  systemd support.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + DOAP updates.
  + Updated translations.
* Sat Jul 19 2014 zaitor@opensuse.org
- Update to version 3.13.3:
  + Fixes for XDG_CURRENT_DESKTOP semantic shift.
  + Updated translations.
* Thu Jun 12 2014 cxiong@suse.com
- Pass extra environment variables into DBus-activated service
  + Add gnome-session-pass-env-to-dbus.patch
    Fix missing env vars issue in DBus-activated service.
    see (bnc#869677)
* Mon May 19 2014 fezhang@suse.com
- Disable logging to systemd journal (bnc#876685)
  + Add gnome-session-disable-logging-to-systemd-journal.patch
* Tue Apr 15 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Add DesktopNames to session files.
  + doap file updates.
  + ConsoleKit fixes.
  + Updated translations.
* Sat Apr  5 2014 dimstar@opensuse.org
- Fix dependency of gnome-session-wayland: require
  gnome-shell-wayland instead of regular gnome-shell.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Fix for wayland support.
* Thu Mar 20 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Update FSF address in copyright headers.
  + Small wayland update.
  + Improve xtrans autogoo.
  + Updated translations.
* Tue Mar 11 2014 sreeves@suse.com
- Add gnome-session-commit-07852f0.patch.
    Fix a possible crash in the presence interface
* Thu Mar  6 2014 dimstar@opensuse.org
- Add pkgconfig(xtrans) BuildRequires: we lost this when the
  Xorg-stack was reorganized, and as configure did not mark it
  mandatory, it 'slipped', resulting in bnc#862331 and bnc#867772
  (gnome-session listens on remote TCP sockets).
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Fix crash on startup for non-systemd systems.
  + Updated translations.
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Warning fixes.
  + Use modern methods for finding gsettings schemas.
  + fail whale size request fixes.
  + Updated translations.
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Blacklist nv25
  + Use new GSubprocess api
  + Updated translations.
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Fix a possible crash in the presence interface.
  + gsm-manager: Don't abort when all clients exit (bgo#710480).
  + gsm-util: Use g_unsetenv() rather than g_setenv(variable, NULL)
    (bgo#710485).
  + Only support UPower 0.9.
  + Drop EggSMClient.
  + Remove gnome-session-properties (bgo#708923).
  + Updated translations.
- Drop gnome-session-upower.patch: fixed upstream.
* Wed Mar  5 2014 cxiong@novell.com
- Remove special code for GNOME classic: it was introduced because
  of a bug in XDM that messed arguments up (bnc#866874).
* Mon Mar  3 2014 cxiong@novell.com
- remove gnome-session-properties as in upstream.
  See bnc#863709 and bgo#708923.
* Mon Dec  9 2013 mgorse@suse.com
- Add gnome-session-upower.patch: Only use UPower API when building
  against UPower <= 0.9.22. In any other case, the respective
  functionality is provided by systemd.
- Drop pkgconfig(upower-glib) BuildRequires: due to above patch,
  there is no longer any need for UPower.
* Fri Oct 11 2013 dimstar@opensuse.org
- Update to version 3.10.1 (bnc#845551):
  + Fix a crash on session end (bgo#709221).
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Put gnome-shell-wayland.desktop in /usr/share/wayland-sessions
    instead of /usr/share/xsessions.
  + Updated translations.
* Wed Sep 18 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add basic support for running Wayland sessions.
  + Updated translations.
- Create new subpackage gnome-session-wayland, containing the
  wayland support. As we don't have wayland in running state in
  openSUSE 13.1, there is no need to pull this in for everybody,
  but we also do not want to make it extra difficult to start
  exploring wayland features.
- Clean up spec file, drop old language hacks, dating back to
  openSUSE <= 11.2.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Add new phase for gnome-initial-setup and new phase for
    mutter-wayland.
  + Fix deadlock now that idle handling is in mutter.
  + Drop dead fallback code.
  + Add bits needed for wayland integration.
  + Rename session-properties to gnome-session-properties.
  + Make shutdown and reboot failable operations.
  + Misc fixes.
- Drop gnome-session-kdm-support.patch: with the removal of the
  already previous dead fallback code, this patch turned useless.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Code style fix ups.
  + Set _GNOME_IS_SOFTWARE_RENDERING root window property when
    software rendering.
  + Disable hardware acceleration for poulsbo driver.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Check errors on D-Bus calls (bgo#705163).
  + Set up journal redirection earlier (bgo#703661).
  + Reshow end session dialog when inhibitor disappears
    (bgo#702575).
  + Updated translations.
* Wed Jun 26 2013 mgorse@suse.com
- Fix gnome-session-kdm-support.patch: gcc 4.8 became stricter in
  the use of snprintf.
* Wed May 15 2013 dimstar@opensuse.org
- Update to version 3.8.2.1:
  + Always distribute session-selector.ui (bgo#700363).
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Make GsmAutostartApp work with new GLib (bgo#698798).
- Disable translation-update-upstream: it fails and has no newer
  translations anyway.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Check for logind, not systemd (bgo#696262).
  + Updated translations.
* Sat Apr 13 2013 dimstar@opensuse.org
- Modify gnome starter script: if the first parameter is
  'gnome-classic', that means we want to start gnome-session with
  - -session gnome-classic (we need to inject --session into the
  build command).
* Tue Apr  2 2013 dimstar@opensuse.org
- Drop gnome2-look-and-feel package and obsolete it from the main
  package. The replacement is called gnome-shell-classic and is
  built by gnome-shell-extensions.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Increase phase timeout to 90 seconds.
  + Updated translations.
- Obsolete gnome-session-fallback-session: GNOME 3.8 removed the
  fallback session mode.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Use pkg-config to check for X libraries.
  + Automatically fallback to software renderering if hardware
    renderering doesn't pass the sniff test.
  + fix positioning of fail whale dialog.
  + Updated translations.
- Add pkgconfig(x11) BuildRequires: new verified dependency.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Add preliminary patch toward systemd-ification.
  + Fix XSMP clients after shutdown is canceled.
  + Make build with newer upower.
  + Adjust for new gnome-desktop idle api.
  + Add session selector.
  + Set XDG_MENU_PREFIX.
  + Updated translations.
- Drop gnome-session-selector.patch: fixed upstream.
- Drop gnome-session-properties-remove-help.patch: fixed upstream.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Remove the fallback session definition (bgo#687586).
  + Remove support for RequiredProviders (bgo#691663).
  + Show the fail whale if GNOME shell can't run (bgo#687586).
  + Log to the systemd journal when available (bgo#691785).
  + Make SIGUSR1 print a line in debug output (bgo#692241).
  + Add an InhibitedActions D-Bus property (bgo#692517).
  + Reduce default idle timeout to 2 minutes.
  + Move automatic logout on idle functionality to
    gnome-settings-daemon (bgo#597030).
  + Allow empty sessions (bgo#690866).
  + Allow named saved sessions (bgo#613270).
  + Updated translations.
- Drop fallback-session package: the fallback mode has been removed
  upstream. A collection of extensions is available to reproduce
  a GNOME 2 Look and Feel.
- Drop pkgconfig(libnotify) BuildRequires: no longer needed.
- Add gnome-session-selector.patch: Don't install session-selector
  man-pages and .ui files if the session-selector is not being
  installed.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Use GnomeIdleMonitor for idle detection
  + Enable llvmpipe
  + Fix some error spew
  + Make --version not return a failure code
  + Reduce depedency on GTK+
  + Shutdown and logout fixes
  + Add automatic logout on idle feature
  + Docs fixes
  + Misc fixes
  + Updated translations.
- Add pkgconfig(gnome-desktop-3.0), pkgconfig(gio-unix-2.0) and
  pkgconfig(libnotify) BuildRequires: new dependencies.
- Drop gnome-session-unblacklist-llvmpipe.patch: fixed upstream.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Be more careful when dropping system inhibitors.
  + Add a commandline wrapper for inhibiting.
  + Add a GetLocale() D-Bus method.
  + Add a SessionIsActive D-Bus property.
  + Modernize the code in some places.
  + Initialize GsmSystem before acquiring a bus name.
  + Properly initialize upower client.
  + Reject xsmp clients sooner when ending the session.
  + Set _GNOME_MAX_SCREEN_SIZE root window property.
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Add gnome-screensaver to fallback session.
  + Make SessionName property introspectable.
* Mon Feb 18 2013 mike.catanzaro@gmail.com
- Add gnome-session-properties-remove-help.patch (bnc#804180) from
  upstream git to remove the help button in "Startup Applications"
  which points to nowhere.
* Fri Nov 16 2012 dimstar@opensuse.org
- Only conditionally require ConsoleKit from gnome-session-core,
  based on with_systemd defines: while switching openSUSE 12.3 to
  systemd based session tracking, we should not require CK anymore.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Initialize systemd client before acquiring name. Fixes logind
    race.
  + Add SessionName property to introspection. Fixes gdbus errors.
  + Drop system inhibitor when necessary. Fixes logind leak.
  + Fix malloc/g_free mismatch in systemd code.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Don't fall back for zaphod mode multi-screen setups.
  + Fix build on OpenBSD.
  + Detect greeter sessions better with systemd.
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Make autostart overriding more flexible
  + Updated translations.
* Thu Sep  6 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Updated translations.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Make XSMP error messages more clear
  + Be more careful in systemd code when session fails to get
    registered
  + Require newer glib
  + Make gconf build time optional
  + Updated translations.
- For now we keep pkgconfig(gconf-2.0) BuildRequires for continued
  support of gconf-based autostart.
- Drop pkgconfig(polkit-gobject-1) BuildRequires: no longer needed.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Session Manager:
  - Add command for showing reboot dialog
  - Inhibitor API / mechanism improvements
  - Systemd integration fixes
  - Fail whale in more failure cases
  - Fix duplicate logout dialog when user hits cancel
  - Updated man pages
  + Updated translations.
* Tue Jul  3 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Session Manager:
  - Require new logind version
  - Remove markup from translatable string
  - Fail softer in the face of spotty session bus
  - Consider that required component that exits with 1 has
    crashed
  + Updated translations.
* Mon Jul  2 2012 vuntz@opensuse.org
- Drop gnome-session-bgo507101-tile-ui.patch: the logout dialog is
  only used in the fallback mode, and it's not worth maintaining
  this patch for the fallback mode. Fix bnc#689608.
- Drop gnome-session-sleep.svg source, since it was only needed for
  the above patch.
- Drop gnome-session-wm-switch.patch: this patch was needed when we
  were still supporting compiz in GNOME, but this is not the case
  anymore.
- Remove support for gnome-patch-translation since there are not
  patches adding translations left: remove gnome-patch-translation
  BuildRequires and commented out calls to
  gnome-patch-translation-prepare and
  gnome-patch-translation-update.
- Note that the two patches were disabled since they needed to be
  rebased, so there's no real change, code-wise.
* Wed May 30 2012 badshah400@gmail.com
- Add gnome-session-unblacklist-llvmpipe.patch to remove llvmpipe
  from the list of blacklisted Mesa drivers and enable the full
  gnome-shell experience even on virtual machines (e.g.
  virtualbox).
* Wed May 23 2012 zaitor@opensuse.org
- Update to version 3.4.2.1:
  + Ensure we have a new enough version of systemd.
  + Updated translations.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Capplet: Add Unity to OnlyShowIn in .desktop file
  + Updated translations.
* Mon Apr 16 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Properly move to next phase if an app dies on startup
  + Fix some restart/poweroff problems in the systemd code
  + Cleanups
  + Updated translations.
- Update gnome-session-kdm-support.patch, from Stefan Bruens
  <stefan.bruens@rwth-aachen.de>:
  + Support suspend with KDM
  + Fix crash when cancelling log out
* Mon Apr  2 2012 jhernandez@emergya.es
- Enable systemd support only for openSUSE >= 12.2. On earlier
  versions, don't use libsystemd-daemon/libsystemd-login
  pkgconfig() BuildRequires since systemd is too old there.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Don't show toggle switches for gnome-shell extensions in fail
    whale dialog; simply disable all extensions instead
  + Code cleanups
  + Updated translations.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Minor bug fixes.
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Fix the GsmSystem type registration
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Use systemd session tracking instead of ConsoleKit when system
    is booted with systemd
  + Code cleanups
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Add pkgconfig() BuildRequires for the new support of systemd
  session tracking: libsystemd-login, libsystemd-daemon,
  polkit-gobject-1.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Blacklist pre-R300 Radeon hardware in accelerated check.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Fix regexp for blacklisting Intel 830-865 hardware
  + Updated translations.
- Drop gnome-session-blacklist-hardware.patch: fixed upstream.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + Tools:
  - Look at gnome.fallback={0,1} argument in kernel boot line to
    determine if fallback mode should be enforced or ignored
  - Use whitelist/blacklist regexps in an external file when
    evaluating renderer for accelerated check
  - Blacklist Intel 830-865 hardware when checking for
    accelerated hardware
  + Updated translations.
- Rebase gnome-session-blacklist-hardware.patch: mostly fixed
  upstream, except the regex form in hardware-compatibility.
- Drop gnome-session-gnome.fallback-boot-arg.patch: fixed upstream.
* Tue Oct 25 2011 vuntz@opensuse.org
- Update gnome-session-blacklist-hardware.patch: fix regexp for
  Intel 830-865 hardware blacklisting. Fix bnc#722903.
* Wed Oct 19 2011 vuntz@opensuse.org
- Add gnome-session-gnome.fallback-boot-arg.patch: let users be
  able to pass gnome.fallback=0/1 argument at boot to choose
  fallback/non-fallback mode.
- Add gnome-session-blacklist-hardware.patch: use an external file
  to easily blacklist/whitelist some hardware when checking if
  we have 3d support.
* Sun Oct 16 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Session Manager
  - Refuse to install an idle timeout of 0 seconds
  - Fix crash on Solaris because of bad comparison
  + Updated translations.
* Tue Oct 11 2011 vuntz@opensuse.org
- Update /usr/bin/gnome script to have an installer launcher on the
  panel in fallback mode. We simply copy the panel default layout
  for the live user, and append the definition of the launcher.
  Fix bnc#702671.
* Mon Oct 10 2011 dimstar@opensuse.org
- Provide a gnome2-look-and-feel package that allows the user
  to switch to GNOME 2 look and feel (GNOME Fallback mode) during
  login or as his preferred default session:
  + Simply copy the gnome.desktop X session definition to
    gnome2-look-and-feel.desktop, and start the fallback mode from
    there.
  + This is meant to ease the transition of some users constantly
    requiring the old look and feel.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
- Update /usr/bin/gnome script to improve logging in twice on a
  live image:
  + Use -p with mkdir, to avoid failing when creating a directory
    that already exists.
  + Do not overwrite pre-existing user applications.menu.
  + Do not add a second YaST2-live-installer.desktop favorite for
    gnome-shell.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Session Manager:
  - Never mark as handled the Disconnected signal from dbus
  - Disconnect all dbus clients when dbus is disconnected
  - Don't offer logout in the fail whale on the login screen
  - Code improvements
  + Updated translations.
- Drop gnome-session-dbus-disconnected.patch: fixed upstream.
* Fri Sep  9 2011 vuntz@opensuse.org
- Add gnome-session-dbus-disconnected.patch: this fixes the case
  where the session bus quits before gnome-session, so we can
  properly terminate the session. Helps make the new gdm work.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Session Manager
  - Fix usage of %%lld for 64-bit formats
  - Add a translator comment
  + Updated translations.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Session Manager
  - Support for debugging the fail whale dialog
  - Show gnome-shell extensions in the fail whale dialog
  - Respect lockdown in the fail whale dialog
  - Add an IsSessionRunning DBus method
  - Remove obsolete gconf sanity check
  + Updated translations.
- Add pkgconfig(json-glib-1.0) BuildRequires: new dependency.
- Remove gconf-sanity-check BuildRequires, as well as
  gconf-sanity-check Requires for core subpackage: the gconf checks
  are now gone.
* Fri Aug 12 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Session Manager:
  - Fix --help to mention arguments for options that have one
  - Support XDG_CURRENT_DESKTOP
  + Capplet:
  - Respect OnlyShowIn and NotShowIn keys
  - Code cleanup
  + Updated translations.
* Fri Jul 22 2011 vuntz@opensuse.org
- Update /usr/bin/gnome script:
  + Do not set SDL_AUDIODRIVER and ALSA_CONFIG_PATH environment
    variables. This should be properly configured in
    /etc/profile.d/pulseaudio.sh now, thanks to the fix for
    bnc#707703.
  + Pass arguments to /usr/bin/gnome-session. This makes it
    possible to use the script and still use a non-default session
    (with gnome-session --session XYZ).
* Thu Jul  7 2011 vuntz@opensuse.org
- Update /usr/bin/gnome script for GNOME 3:
  + Remove the migration code for the desktop background: this is
    based on gconf, and the setting moved to GSettings. Since this
    setting is not migrated from gconf anyway, the user will get
    the default background.
  + Do not copy live-installer.desktop on the desktop anymore: the
    desktop is not managed by nautilus by default, so it's useless
    to put it there. Instead, create a custom applications.menu to
    add the installer to System Tools, and add the installer as
    favorite application in gnome-shell. Fix part of bnc#702671.
  + Disable the lock setting of the screensaver with GSettings
    instead of gconf.
  + Disable the check for software updates with GSettings, instead
    of disabling an autostart application (that doesn't exist
    anymore).
  + Generally, this should fix bnc#687778.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Session Manager
  - Fix build warnings
  + Capplet
  - Fix build warning
  + Misc
  - Modernize build system a bit
  - Remove artificial librsvg dependency
  + Updated translations.
- Remove now unneeded pkgconfig(librsvg-2.0) BuildRequires.
* Sat Jul  2 2011 vuntz@opensuse.org
- Split out default-session and fallback-session subpackages, that
  contain the definitions of the upstream default and fallback
  sessions for GNOME. They have Requires matching the session
  definitions.
- Note that we have a fallback-session Recommends in
  default-session, since by definition, the default session could
  fallback to the fallback session. We use a Recommends instead of
  a Requires, since people might want to remove it.
- Remove gnome-panel, gnome-settings-daemon, metacity, nautilus,
  notification-daemon Requires for the main package, as those were
  only used to define the GNOME session. Instead, add a Requires on
  the default-session subpackage.
- Move the gnome-session-check-accelerated and
  gnome-session-check-accelerated-helper tools to the core
  subpackage, as session definitions might use those helpers.
- As a side-effect, these changes should fix bnc#697574.
* Tue Jun 14 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + Fix race condition in idle monitor
  + Consistently use Restart and not Reboot
  + Fix crashes by not assuming XSMP clients set the SmProgram
    property
  + Make the acceleration checks refuse to work in zaphod mode
  + Update libegg code
  + Code cleanups
  + Updated translations.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Session Manager:
  - Change path of GSettings schema
  + Updated translations.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.94:
  + Session Manager: Bump the phase timeout to 30 seconds
  + Updated translations.
- Changes from version 2.91.93:
  + Session Manager:
  - Make work with latest version of the shell.
- Changes from version 2.91.92:
  + Session Manager:
  - Better fatal error handling in general, including specific
    handling when required components fail.
  - Improve wording of fallback dialog.
  - Avoid double-checking between gdm and gnome-session in
    gnome-session-check-accelerated-helper.
  - Switch to using seconds for idle time.
  - Honor disable-log-out and disable-user-switching lockdown
    settings.
  - Change format of .session files in a incompatible way; this
    is now documented in the gnome-session man page.
  - Update gnome-session-quit man page
  - Enforce the use of required components in the session.
  - Deal with conflicts between Provides in different
    applications by only having one provider running; this was
    only working well for Provides defined in the session
    definition.
  - Use app-id when saving session instead of startup-id for
    .desktop.
  - Explicitly require gnome-shell/gnome-panel in .session files,
    instead of using providers.
  - Clean up saved session on logout if session is not getting
    saved.
  - Use "computer-fail" icon from theme instead of our own
    sad-computer.
  - Fix some gnome-shell/gnome-session interaction issue on
    logout, when a third application cancels logout.
  - Code cleanups
- Changes from version 2.91.91.3:
  + Session Manager:
  - Better error message on not-found session.
  - Rename gnome-session-save to gnome-session-quit.
  - Fix cancel button in logout dialog.
  - Increase is-accelerated runnable helper timeout.
  - Fix crash when if-session autostart condition is used.
  - Add gnome-session-check-accelerated to set a X property about
    acceleration
  - Rename gnome-session-is-accelerated to
    gnome-session-check-accelerated-helper.
- Drop gnome-session-fix-autostart.patch: fixed upstream.
- Disable gnome-session-bgo507101-tile-ui.patch for now: it needs
  to be rebased.
* Tue Mar  1 2011 fcrozat@novell.com
- Update to version 2.91.90.1:
  + Session Manager:
  - Fix a crash happening in gdm
  + Updated translations.
- Changes from version 2.91.90:
  + Session Manager:
  - Update for GSettings schemas changes
  - Read default session from GSettings
  - Make the current session name available via dbus
  - Support autostart conditions that depend on the current
    session
  - Make notification-daemon a required part of the fallback
    session
  - Show a dialog after login the first time we fall back to
    gnome-fallback
  - Various fixes to shell logout/shutdown dialog
  - Code cleanups
  + Misc:
  - gsettings-desktop-schemas 0.1.7 is required
  + Updated translations.
- Changes from version 2.91.6:
  + Session Manager:
  - Fix build with latest GTK+ 3
  - Migrate to GSettings
  - Add support for shell logout/shutdown dialog
  - Use fallback session if required components are missing
  + Defined Sessions:
  - Do not consider Gallium's softpipe and llvmpipe as
    accelerated
  - Do not run nautilus by default
  + Capplet:
  - Migrate to GSettings
  + Misc:
  - Change GETTEXT_PACKAGE to gnome-session-3.0
  - Drop gnome-wm script
  - Add a runtime dependency on gsettings-desktop-schemas
  + Updated sranslations.
- Add pkgconfig(librsvg-2.0) BuildRequires.
- Add notification-daemon Requires to main package as it's now
  required by the fallback session.
- Add gnome-session-fix-autostart.patch: fix crash in autostart
  code, taken from git.
- Add gsettings-desktop-schemas Requires to gnome-session-core.
- Remove --with-default-wm=gnome-wm and --enable-splash configure
  options: they're now gone.
- Drop gnome-session-enable-disable-compiz.patch: this should now
  be done another way, with fallback modes in gnome-session. See
  bnc#676360.
* Mon Feb 21 2011 vuntz@opensuse.org
- Update gnome script to fix an issue where users from earlier
  versions of openSUSE could end up with no wallpaper in 11.4:
  + reset the wallpaper configured in the user config if it was
    explicitly set to a default wallpaper from a previous version
    of openSUSE.
  + we do this only once, if
    ~/.config/suse/gnome-11.4-wallpaper-migrated does not exist.
  + note that we're avoiding this issue for future releases since
    the default wallpaper will always keep the same name now.
  + this fixes the issue highlighted in bnc#671564 comment 2.
- Also, still in gnome script: do not disable beagle on live
  images, since we don't ship beagle anymore.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
- Remove 2.x references in summaries and descriptions.
* Thu Dec 23 2010 vuntz@opensuse.org
- Update to version 2.91.4:
  + Session Manager:
  - Add autostart condition through GSettings
  - Don't ever show inhibitor dialog if logout is forced
  - Fix some issue tracking clients on logout
  - Add an application restart limit
  - Move the definition of a session from gconf to .desktop-like
    files
  - Change default session to use GNOME Shell, with a fallback to
    classic GNOME
  - Update for GTK+ 3 changes
  - Code cleanups
  + Capplet:
  - Set NoDisplay=true
  - Fix inline search
  - Update for GTK+ 3 changes
  + Updated translations.
- Add pkgconfig(xcomposite) and pkgconfig(gl) BuildRequires, for
  the new gnome-session-is-accelerated helper.
* Fri Dec 17 2010 vuntz@opensuse.org
- Update to version 2.91.0:
  + Session Manager:
  - Miscellaneous string fixes
  - Fix for GTK+ 3 changes
  + Misc:
  - Update information in README and other files
  - Update man pages
  - Build against GTK+ 3 by default
  - Rename --enable-deprecations configure flag to
  - -enable-deprecation-flags
  + Updated translations.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: gconf2-devel, libupower-glib-devel.
  + New ones: dbus-glib-1, gconf-2.0, glib-2.0, gtk+-3.0, ice, sm,
    upower-glib, xau, xext, xrender, xtst.
- Remove gnome-settings-daemon-devel BuildRequires: it's not
  needed.
- Improve summary and description.
- Rework gnome-session-bgo507101-tile-ui.patch to build with GTK+3.
* Wed Nov 17 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Miscellaneous string fixes
  + Update information in README and other files
  + Update man pages
  + Updated translations.
- Rebase gnome-session-bgo507101-tile-ui.patch.
* Mon Sep  6 2010 vuntz@opensuse.org
- Add X-SuSE-ControlCenter-Personal to session-properties.desktop
  instead of X-SuSE-ControlCenter-System, to make the item appear
  in the right place in menus.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.6:
  + Session Manager:
  - Fix a GSeal issue
  - Fixed spelling error in schema description
  - Port gnome-session to upower
  - Fix description of auto_save_session key
  + Drop compatibility tool that sets GTK+ 1.x environment variable
  + Drop the splash program
  + Require upower-glib instead of devkit-power-gobject
  + Add configure flag to select which GTK+ version to use
  + Updated translations.
- Change DeviceKit-power-devel BuildRequires to
  libupower-glib-devel.
- Rebase gnome-session-bgo507101-tile-ui.patch.
- Drop gtk1-support and splash subpackage, and obsolete those
  packages.
* Thu Jul  8 2010 dimstar@opensuse.org
- Update to version 2.31.2:
  + Export _stop method for clients, for better GNOME Shell
    experience
  + Explicitly add -lXext -lXau to linker line
  + Updated translations.
* Mon Jun 14 2010 vuntz@opensuse.org
- Export XDG_MENU_PREFIX=gnome- in /usr/bin/gnome. This lets us use
  gnome-applications.menu to define the applications menu
  structure. This fixes various bugs, including bnc#595912.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun May 23 2010 guido+opensuse.org@berhoerster.name
- Split off a -core subpackage with a minimal runtime version
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Log out on SIGTERM and SIGINT
  + Delay the creation of the GsmXSMPClient until it really exists,
    to fix potential crashes on logout
  + Remove unneeded LIBGNOMEUI_REQUIRED from configure.in
  + Updated translations.
* Fri Feb 12 2010 vuntz@opensuse.org
- Update gnome script:
  + Remove migration code of panel configuration. It was only
    needed up to SLED11. SLED11 has been released, and we're
    openSUSE, so it's safe to remove it.
  + Make the code fixing the background configuration run only for
    non-openSUSE branded distributions. We don't want it in
    openSUSE since it runs gconftool-2, and might slow down login a
    bit.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.29.6:
  + Session Manager:
  - Fix typo in error message
  - Add diagnostic output for exit phase timeout
  - GSeal: Use accessor functions instead of direct access
  - Check that the XSMP connection exists when stopping a client
    to fix potential crash on exit
  + Capplet:
  - Destroy the main window on close to ensure changes are saved
  + Misc:
  - Install the helpers in libexecdir, not libdir
- Rebase gnome-session-bgo507101-tile-ui.patch.
- Drop gnome-session-fix-capplet-saving.patch: fixed upstream.
- Remove en@shaw translation on openSUSE 11.2 and earlier.
* Fri Dec  4 2009 vuntz@opensuse.org
- Add BuildRequires and Requires on gconf-sanity-check, which was
  split from the main gconf2 package.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the ha/ig locales for old versions of
  openSUSE.
* Tue Dec  1 2009 vuntz@opensuse.org
- Split the gnome-settings-daemon helper into a gtk1-support
  subpackage, that will only gets installed if gtk1 is installed.
  This should remove some unneeded cruft on login for most people.
- Add --enable-splash configure option, and ship the splash screen
  in a splash subpackage.
- Fix rpmlint warning about self-obsoletion.
- Fix license: it's GPLv2+ and not "GPLv2+;LGPLv2.1+".
* Mon Oct 12 2009 vuntz@opensuse.org
- Add gnome-session-fix-capplet-saving.patch taken from upstream,
  to fix saving the autostart changes when quickly quitting the
  capplet after doing a change.
* Fri Oct  2 2009 vuntz@opensuse.org
- Update gnome script for the Live CD:
  + Make screensaver not lock the screen by default on LiveCD.
  + Make sure the "Live Installer" icon is visible on the desktop
    of the user. Because of xdg-user-dirs, the desktop directory is
    not always ~/Desktop, so we have to look at
    ~/.config/user-dirs.dirs first.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Trivial code fixes
  + Lock the screen before hibernate/suspend
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Remove at-spi-registryd wrapper (at-spi properly implements
    session management)
  + Updated translations.
- Remove now non-existing --with-at-spi-registryd-directory
  configure option.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 2.27.91:
  + Install splash desktop file in $(sysconfdir)/xdg/autostart
  + Do not install gnome-splash.png unless --enable-splash is used
  + Fix idle watch not working
  + Fix typo in debug message
  + Use GTK+ accessor functions instead direct access
  + Remove deprecated Encoding key from desktop file
  + Port to PolicyKit 1
  + Remove dependency on PolicyKit libraries
  + Updated translations.
- Drop gnome-session-polkit1.patch: fixed upstream.
- Respin gnome-session-bgo507101-tile-ui.patch.
- Use spec-cleaner to reorder lines in preamble.
* Wed Aug 19 2009 vuntz@novell.com
- Add Requires on ConsoleKit: it's needed to have gnome-session
  work properly.
* Thu Aug  6 2009 vuntz@novell.com
- Add gnome-session-polkit1.patch to fix reboot/shutdown options
  being disabled.
- Remove PolicyKit-gnome-devel BuildRequires.
* Thu Aug  6 2009 vuntz@novell.com
- Change Recommends to Requires for gnome-panel,
  gnome-settings-daemon, metacity and nautilus. This should fix the
  problem of people seeing an empty GNOME session if they only have
  gnome-session installed. Fix bnc#523774.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Prefer compiz-manager over compiz when available in gnome-wm
  + Add --with-default-wm configure option to let distributors
    specify the default window manager they want to use (including
    gnome-wm)
  + Use silent-rules with automake 1.11
  + Add --enable-splash configure option to build splash, and
    disable splash build by default
  + Add Presence interface to the documentation
  + Do not exit when the system bus restarts
  + Port from gnome-power-manager to DeviceKit-power
    DeviceKit-power is a new dependency.
  + Code cleanup
  + Updated translations.
- Add DeviceKit-power-devel BuildRequires.
- Pass --with-default-wm=gnome-wm to configure.
- Provides and Obsoletes branding package, and remove
  branding-upstream package as we don't ship the splash anymore.
- Remove splash-related packaging.
- Respin gnome-session-bgo507101-tile-ui.patch.
- Remove gnome-session-gnome-wm-compiz-manager.patch and
  gnome-session-compiz-as-default-wm.patch, and replace them with
  gnome-session-enable-disable-compiz.patch.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.27.4:
  + Reduce GConf roundtrips
  + Use shave to improve build log readability
  + Fix a crash on Solaris
  + Generate docs for the presence API
  + Rewrite a good part of the capplet. Some highlights:
  - much cleaner code
  - monitor autostart files
  - autofill name field if needed
  - add help button
  - better handling of themed and non-themed application icons
  - allow dragging from the application list
  - make it more clear that applications are disabled
  + Port to GtkBuilder
  + Improve debug message
  + Load default apps after saved and autostart apps
  + Build fixes for BSD
  + Update eggsmclient code to fix crash
  + Add mutter support to gnome-wm
  + Make gnome-session exit properly on reboot/shutdown
  + Avoid pointless warnings
  + Honour the SmRestartNever SmRestartStyleHint
  + Default clients to RESTART_IF_RUNNING instead of NEVER
  + Code cleanups
  + Updated translations.
- Rebase gnome-session-bgo507101-tile-ui.patch.
- Rebase gnome-session-gnome-wm-compiz-manager.patch.
- Remove libglade2-devel BuildRequires.
- Use gnome-autogen.sh instead of autoreconf to make it work.
* Mon May 25 2009 vuntz@novell.com
- Update gnome-session-gnome-wm-compiz-manager.patch to enable
  compiz only if the compiz-enabled file is newer than
  /etc/X11/xorg.conf
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + Fix inhibitor dialog not showing the right action button when
    shutting down
  + Make gnome-session-save --kill --silent work as --force-logout
  + Correctly use the arguments passed to gnome-session when
    launched with no session dbus
  + Updated translations.
* Wed Apr  8 2009 vuntz@novell.com
- Update to version 2.26.0.90:
  + New version with two main changes:
  - gnome-session now lets applications properly exit on logout
  - saving a session on logout is activated again
  + Detailed changes:
  - Update man pages
  - Let all processes exit cleanly on logout/reboot/shutdown
  - Use smaller icon size in inhibit dialog
  - Fix various crashes in inhibit dialog and during the logout
    process
  - Make the inhibit dialog look at desktop files from autostart
    directories too
  - Use XDG_CONFIG_HOME to save the session and create the
    session directory with the right permissions
  - Get the discard command from XSMP clients and save it when
    saving a session, and use it when removing a saved session
  - Properly handle XSMP clients that don't return a restart
    command when saving the session
  - Various XSMP protocol fixes
  - When saving the session, ask the XSMP clients to save the
    global and local states when needed instead of just asking
    them to save their global states.  Else, clients won't appear
    on next login
  - Allow XSMP clients to interact during the logout (and cancel
    the logout), using the inhibit infrastructure
  - Allow clients to specify that they want to be ended last
  - Hide deprecated command-line options from gnome-session-save
  - -help
  - Re-enable session saving
  - Ignore XSyncAlarmDestroyed events, to avoid filling
    ~/.xsession-errors
  - Various code cleanups
  - Updated translations.
- Stop recommending control-center2: I see no reason why we'd want
  to do this. Instead, recommend gnome-panel, metacity, nautilus
  and gnome-settings-daemon.
  since they are in the default session.
- Stop suggesting rsh: it's not used anymore.
* Thu Mar 19 2009 vuntz@novell.com
- Remove workaround adding gnomesu to live-installer.desktop. It's
  not needed anymore. Will fix bnc#486644.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Turn off debug spew
  + Hide the "Save current session" button in the session
    properties since it's not working
  + Disable session saving because it's not ready yet
  + Updated translations.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.92:
  + Ensure treeview is included in a scrolled window with a shadow
    in the inhibit dialog
  + Use system-log-out icon instead of deprecated gnome-logout
  + Implement session saving
  + Use close button instead of ok button for error dialog
  + Fix the logout dialog not being themed
  + Code cleanup
  + Updated translations.
* Sat Feb 28 2009 vuntz@novell.com
- Requires dbus-1-x11: gnome-session needs dbus-launch.
* Mon Feb 23 2009 vuntz@novell.com
- Update to version 2.25.91:
  + Fix copy & paste error in debug output
  + Avoid restarting applications when shutting down
  + Improve logout/shutdown dialog messages
  + Change the capplet name in
  + Remove obsolete logout_option gconf key
  + Update description of required_components_list gconf key
  + Updated translations.
- Remove BuildRequires: gnome-desktop-devel, gnome-keyring-devel,
  libgnomekbd
- Add BuildRequires: gconf2-devel
- Do not pass unknown --with-rsh-command configure option
- Respin gnome-session-bgo507101-tile-ui.patch.
* Thu Feb 19 2009 vuntz@novell.com
- Don't requires bug-buddy anymore. This is not the case since
  2.23.x.
* Thu Feb  5 2009 mboman@suse.de
- Update to version 2.25.90:
  + Install autostart files in /etc/xdg/autostart
  + Use 22x22 icons in the splash screen
  + Fix a potential crash in the splash screen
  + Fix dbus documentation to mention the session bus instead of
    system bus
  + Fix build when XTest is not available
  + Fix generation of dbus documentation to have valid docbook
  + Translation updates
- Remove gnome-session-bnc389137-splash-layout.patch. Fixed
  upstream
* Sat Jan 31 2009 mboman@suse.de
- Update to version 2.25.5:
  + Close ICE connection for qt3 applications
  + In all phases before APPLICATION, consider process termination
    as completion
  + Fix gnome-session not looking at $XDG_DATA_HOME/applications
  + Correctly check for sm and ice libraries in configure script
  + Correctly handle X-GNOME-Autostart-enabled=false in
    gnome-session-properties
  + Add support for --enable-polkit/--disable-polkit in configure
    script (default is still automatic)
  + Add NoDisplay=True to desktop files
  + Fix typo in error message
  + Double-click startup program entry to open edit dialog in
    gnome-session-properties
  + Fix apps with an icon not existing in the icon theme displayed
    with no icon
  + Add 48x48 icon for session properties
  + Add a presence dbus API
  + Translation updates
- gnome-session-compiz-as-default-wm.patch has been updated (partly
  fixed upstream)
* Sun Jan 25 2009 vuntz@novell.com
- Call %%suse_update_desktop_file on all desktop files. Part of
  bnc#445728.
- Remove check for old openSUSE distribution.
- Remove BuildRequires on control-center2-devel.
* Fri Jan  2 2009 mboman@suse.de
- Update to version 2.25.3:
  + Address issue with multiple clients trying to use the QueryEndSession
    dbus API
  + Code and build system cleanups
  + Stop using deprecated API
  + Remove libgnomeui dependency
  + Don't link to gnome-keyring and libgnomeui where we don't need
  + Make the session properties dialog resizable
  + Don't try to print an undefined error message
  + Build fixes
  + Rewrite the application finding code for the manager
  + Add new dbus api to say whether shutdown dialog is available
  + Remove compat wrapper for gnome-keyring session interaction
  + Single include fixes for glib
  + Translation updates
* Wed Nov 19 2008 vuntz@novell.com
- Uncomment gnome-patch-translation-prepare and
  gnome-patch-translation-update calls. We need them for
  gnome-session-bgo507101-tile-ui.patch. Part of bnc#445352.
* Wed Nov 12 2008 vuntz@novell.com
- Call %%suse_update_desktop_file on
  %%{_datadir}/xsessions/gnome.desktop so that it can get additional
  translations.
* Thu Nov  6 2008 vuntz@novell.com
- Move suse.svg and suse-help.svg to gconf2-branding-openSUSE,
  since that's where the desktop files were moved to.
- Remove libnotify-devel BuildRequires. It's not required.
* Tue Oct 28 2008 rodrigo@novell.com
- Update gnome-session-compiz-as-default-wm.patch to not try
  starting compiz if the ~/.config/compiz/disable-compiz file
  exists (bnc#436873)
* Wed Oct 22 2008 maw@suse.de
- Update to version 2.24.1:
  + Add GTK and GNOME categories to session-properties.desktop
  + Fix leaks
  + Rename variable to avoid symbol conflict
  + Fix padding and spacing, and make the dialog resizable in
    gnome-session-properties
  + Make the strings appear translated in gnome-session-properties
  + Updated translations.
* Tue Oct 21 2008 vuntz@novell.com
- Rebase gnome-session-bgo507101-tile-ui.patch.
  Fix bnc#437090.
* Tue Oct 14 2008 meissner@suse.de
- added prototype
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.24.0:
  + Convert the username to UTF-8 in the logout dialog
  + Fix leaks
  + Turn off debugging by default
  + Updated translations.
* Mon Sep 22 2008 federico@novell.com
- Removed SuSE.desktop and GnomeOnlineHelp.desktop from the sources,
  as well as the logic in the /usr/bin/gnome script to copy these
  files to the user's Desktop.  This is now handled in the
  gconf2-branding-openSUSE package, as Nautilus can now handle desktop
  items defined by the sysadmin.
* Thu Sep 11 2008 rodrigo@suse.de
- suse_update_desktop_file the gnome-wm.desktop file.
- Added Hidden=true to gnome-wm.desktop file.
* Wed Sep 10 2008 rodrigo@suse.de
- Updated gnome-session-compiz-as-default-wm.patch to be more
  correct and to include gnome-wm.desktop file in the package
* Wed Sep 10 2008 rodrigo@suse.de
- Update to version 2.23.92:
  + Make all desktop files translatable (Vincent Untz)
  + Avoid gnome-wm launching itself in loop (Vincent Untz)
  + Remove required components from the default session (Vincent Untz)
  + Rename /desktop/gnome/session/required_components key (Vincent Untz)
  + Do not use dash but underscore to separate words in gconf keys
    (Vincent Untz)
- Added gnome-session-compiz-as-default-wm.patch to run compiz
  as default window manager whenever possible (fate#304762)
* Tue Sep  9 2008 vuntz@novell.com
- Add BuildRequires on PolicyKit-gnome. Fix bnc#422848.
* Thu Sep  4 2008 mboman@novell.com
- Update to version 2.23.91:
  + Bugs fixed: bgo#548710, bgo#548909, bgo#548980, bgo#548982,
    bgo#546863, bgo#550211, bgo#542880, bgo#547272
  + Honor the list of required apps in the list key instead of loading all
    component keys in the dir
  + Look in app dirs for required components
  + Do not use and install gnome-wm by default
  + Add command line option to override the gconf key used to look up the
    default session
  + Fix add/edit dialog of the capplet
  + Fix leaks
  + Code cleanups
  + Translation updates
- Removed gnome-session-launch-dbus.patch. Fixed upstream.
- Removed gnome-session-bgo550211-gnome-session-save-logout.patch.
  Fixed upstream
* Mon Sep  1 2008 vuntz@novell.com
- Remove gnome-session-tile-ui.patch and add instead
  gnome-session-bgo507101-tile-ui.patch that implements the
  tile-based logout dialog. It's a patch I did for upstream.
- Add gnome-session-sleep.svg as a temporary suspend icon. It
  comes from libssui. We'll be able to remove it when upstream
  ships with a suspend icon in gnome-icon-theme.
- Add gnome-session-bgo550211-gnome-session-save-logout.patch to
  add gnome-session-save command line options.
- The goal of this update is to make it possible to get rid of
  libssui.
* Thu Aug 21 2008 vuntz@novell.com
- Update to version 2.23.90:
  + Remove inhibitors for the client when it disconnects
  + Add log/debugging framework
  + Add signal handling framework
  + Add support for stopping/killing apps
  + Add command line option to override autostart dirs (used by
    GDM)
  + Improve QES,ES,CES error handling
  + Remove gnome-login-sound (replaced by libcanberra-login-sound)
  + Rework the capplet dialogs to use gobject.
  + Make gnome-session-save tool use D-Bus API
  + Fixed bgo#521413, Fixes for sparse warnings in gnome-session
  + Fixed bgo#546410, splash no longer disappear
  + Fixed bgo#546439, missing include for pid_t
  + Fixed bgo#546722, Need bump dbus-glib dependency to 0.76
  + Fixed bgo#546896, crash wen passing null strings to
    key_file_set_locale_string()
  + Fixed bgo#547069, [patch] Logout by sending XSMP
    SaveYourselfRequest is broken
  + Fixed bgo#547443, crashes on desktop parsing errors
  + Fixed bgo#547619, gnome-session 2.23.6 doesn't compile on
    Solaris
  + Fixed bgo#547769, part of gnome-wm potentially can break
  + Fixed bgo#548129, gnome-session-properties doesn't create
    ~/.config/autostart
  + Fixed bgo#548259, g-s thinks that metacity is 'not responding'
    if it was --replace'd
  + Updated translations.
- Add gnome-session-launch-dbus.patch to make sure that dbus is
  running (bgo#546863).
* Mon Aug 11 2008 maw@suse.de
- Update to version 2.23.6:
  + This release merges the D-Bus based branch in GNOME SVN into
    the mainline
  + Isolate old XSMP code as much as possible, and change
    gnome-session's design to not be based upon the XSMP lifecycle
  + Add a native D-Bus session management interface
  + Provide an adapter interface for legacy XSMP clients
  + Autostart changes:
  * Improved integration
  * New functionality to provide future extensibility
  + Provide an "inhibit" API for clients to proactively inform
    session management that they're busy
  + Provide an improved logout experience
- Respin gnome-session-bnc389137-splash-layout.patch,
  gnome-session-kde-support.patch,
  gnome-session-ice-auth-for-suid.patch, and
  gnome-session-wm-switch.patch (thanks, Vincent).
* Fri Aug  1 2008 mauro@suse.de
- gnome-session-lang added to the gnome-session package
  + This fixes bnc#412155
* Mon Jul 21 2008 hpj@suse.de
- gnome-session-suspend.patch removed; no longer needed and code
  changed radically.
- gnome-session-DESKTOP_LAUNCH.patch removed; no longer needed.
- gnome-session-remove-dns-warning.patch removed; no longer needed
  as the code in question was also removed from upstream.
- gnome-session-2.12.0-su-session-management.patch rewritten and
  renamed to gnome-session-ice-auth-for-suid.patch. Performs same
  function as before.
- gnome-session-2.19.92-kdm-support.patch rewritten and renamed
  to gnome-session-kdm-support.patch. Performs same functions as
  before.
- gnome-session-motd.patch removed; not the right solution and
  there is discussion upstream about solving it there. Also does
  not have any BNC bug justifying its existence.
- gnome-session-wm-switch.patch rewritten/rebased.
- gnome-session-no-devel-fatals.patch removed; no longer needed.
- gnome-session-2.20.0-safe-a11y-startup.patch removed; no longer
  needed. Was changing the order of startup for daemons - new
  upstream codebase fixes this.
- gnome-session-gcc4.3-fixes.patch removed; no longer needed.
- gnome-session-parse-autostart-command-line.patch removed; no
  longer needed.
- gnome-session-include-unistd.patch removed; no longer needed.
- gnome-session-bnc385150-performance-hostname.patch removed; no
  longer needed. The new upstream code specifically addresses this.
- gnome-session-gnome-wm-compiz-manager.patch rebased; only path
  changed.
- gnome-session-bnc389137-splash-layout.patch rebased. Dropped the
  padding changes, but kept the change in icon size. Upstream
  padding increased, more than matching ours. May need further
  adjustment.
* Fri Jun 27 2008 mauro@suse.de
- Update to version 2.23.4.1
- Brand new code base, to know the new architecture, go to:
  http://live.gnome.org/SessionManagement/NewGnomeSession
- Capplet ported to the new code base.
- Shutdown of D-bus, XSMP and Gconf when session is over.
* Wed Jun  4 2008 rodrigo@suse.de
- Added 'export ALSA_CONFIG_PATH=/etc/alsa-pulse.conf' to gnome
  startup script to make ALSA apps read our specific PulseAudio-
  based setup`(bnc#394177)
* Tue Jun  3 2008 rodrigo@suse.de
- Export SDL_AUDIODRIVER=pulse in gnome startup script to have
  SDL applications use PulseAudio when in GNOME (bnc#394721)
* Sat May 24 2008 sreeves@suse.de
- Update the "gnome" script to not start gpk-update-icon on live install
  BNC #390658
* Mon May 19 2008 sbrabec@suse.cz
- Added needed desktop files and icons from gnome2-SuSE
  (bnc#388735).
* Fri May 16 2008 vuntz@suse.de
- Fix a crash in gnome-session-wm-switch.patch when there's no
  client id in the saved session. Fix bnc#391305
* Thu May 15 2008 olh@suse.de
- remove unneeded Recommends: -64bit on ppc (bnc#390761)
* Thu May 15 2008 vuntz@suse.de
- Add gnome-session-bnc389137-splash-layout.patch to fix
  bnc#389137: the layout of text & icons is not optimal with our
  splash screen.
* Tue May 13 2008 vuntz@suse.de
- Rewrite the logic in gnome-session-wm-switch.patch so that it
  correctly handles compiz (because of compiz-manager).
* Tue May 13 2008 vuntz@suse.de
- Update gnome-session-gnome-wm-compiz-manager.patch to look for
  the right file for compiz activation. Fix bnc#389648, thanks to
  Jigish Gohil.
* Tue May  6 2008 rodrigo@suse.de
- Updated gnome-session-parse-autostart-command-line.patch to
  deal also with %%U arguments in .desktop files (bnc#242907)
* Mon May  5 2008 vuntz@suse.de
- Drop gnome-session-compiz.patch and replace with
  gnome-session-gnome-wm-compiz-manager.patch to correctly start
  compiz-manager when the user has configured this.
* Thu May  1 2008 vuntz@suse.de
- Work around bnc#379332 for the live installer desktop file in the
  gnome script by changing the Exec key to use gnomesu.
* Wed Apr 30 2008 vuntz@suse.de
- Add gnome-session-bnc385150-performance-hostname.patch to fix
  performance issue when launching new apps in GNOME on a default
  beta1 install -- extreme slowness can happen depending on the
  network setup. Fix bnc#385150, patch by Michael Meeks.
* Tue Apr 29 2008 vuntz@suse.de
- Actually copy the right live-installer.desktop (instead of a
  non-existing file) in gnome script so the installer icon appears
  on the desktop.
* Tue Apr 22 2008 vuntz@suse.de
- Remove old PATCH-NEEDS-REBASE tag for
  gnome-session-wm-switch.patch. I forgot to remove it in the
  previous submission.
* Mon Apr 21 2008 vuntz@suse.de
- Drop gnome-session-sound.patch, it's fixed another way upstream.
- Update gnome-session-wm-switch.patch so that it applies.
* Wed Apr 16 2008 jpr@suse.de
- Check for existence of
  /usr/share/applications/YaST2/live-installer.desktop to indicate
  a live CD in the gnome script
* Mon Apr 14 2008 sbrabec@suse.cz
- Removed /usr/bin/gnome code modifying default background in user
  gconf database (bnc#369924).
- Use packageand form of branding supplement.
* Fri Apr 11 2008 maw@suse.de
- Update to version 2.22.1.1:
  + Migrate Trash files to the new trash location (and fix a bug
    therein)
  + Updated translations.
* Fri Mar 28 2008 rodrigo@suse.de
- Added gnome-session-parse-autostart-command-line.patch to deal
  correctly with placeholders in command lines (bnc#180126)
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Remove hard esound dependency
  + Don't start the sound server, and play the login sound when
    gnome-settings-daemon tells us the sound server has started
  + Updated translations
* Mon Mar 10 2008 sbrabec@suse.cz
- Require bug-buddy and its bi-arch counterpart (bnc#354164).
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Require recent versions of gnome-keyring
  + Correctly handle the env. variables given by gnome-keyring to
    make it work in the whole session
  + Updated translations.
* Tue Mar  4 2008 sbrabec@suse.cz
- Split branding subpackage (fate#301792).
* Wed Feb 20 2008 maw@suse.de
- Update to version 2.21.91:
  + Make login sound work again
  + Updated translations.
* Wed Feb  6 2008 jpr@suse.de
- Remove gnome-session-2.12-0-unlock-keyring.patch, gnome-keyring-pam
  covers this and doesn't require CASA
- Remove gnome-session-migrate-session-manual.patch it was obsoleted
  by the fix for bgo334066
- Remove gnome-session-2.12.0-xgl-display-modal-2.patch, upstream
  handles compositing managers now (not quite as pretty, but
  sufficient)
- Remove gnome-session-splash-screen.diff its obsoleted by bgo116814
  (originally bnc5780)
- Remove handling of SUSE Linux 10.0 in the spec, its EOL
* Thu Jan 31 2008 maw@suse.de
- Update to version 2.21.90:
  + Set orientation with randr too (Luca Cavalli)
  + Fix warnings and plug leaks
  + HIG fixes
  + Remove randr calls; they are done by gnome-settings-daemon now
  + Use max dithering again for splash
  + Change capplet title
  + HIG fixes in the capplet
  + Updated translations.
* Fri Nov  9 2007 hpj@suse.de
- Rename gnome-session-main-init.patch to
  gnome-session-2.20.0-safe-a11y-startup.patch, and change it so
  a11y is started up before the user session, but still after
  exporting necessary env vars. Fixes part of Novell bug #332498.
* Wed Nov  7 2007 maw@suse.de
- Update to version 2.20.1
  + Now requires a newer version of gtk2
  + Updated translations
- Add gnome-session-gcc4.3-fixes.patch.
* Thu Sep 20 2007 cgaisford@novell.com
- Updated gnome script to detect live install user and create
  desktop entires in the ~/.config/autostart directory to disable
  beagle and opensuse-updater applets.  Bug #326801
* Wed Sep 19 2007 cgaisford@novell.com
- Updated gnome script to create live install desktop file if the
  system is booted into a live install configuration.  Also depends
  on an update to the gnome2-SuSE package which contains the desktop
  file.  Bug #310543
* Wed Sep 19 2007 mauro@suse.de
- Update to version 2.20.0
  + Updated translations
* Fri Sep 14 2007 cgaisford@novell.com
- Modified the gnome script to copy the SuSE.desktop file to the
  desktop which points to the greeter app #300773
* Thu Sep 13 2007 jpr@suse.de
- Ensure ~/Desktop exists before copying to it (#310363)
* Thu Sep 13 2007 sbrabec@suse.cz
- Fixed background resetting in /usr/bin/gnome (#309946).
* Thu Sep 13 2007 cgaisford@novell.com
- Fixed up kdm-support patch to support gnome sessions in KDM
  Novell Bug #308022
* Mon Sep 10 2007 maw@suse.de
- Update to versino 2.19.92:
  + Fix compiz support in gnome-wm
  + Updated translations.
* Fri Sep  7 2007 lewing@suse.de
- Copy GnomeOnlineHelp.desktop to ~/Desktop the first time 10.3
  runs. Part of bnc #300773
* Thu Sep  6 2007 cgaisford@novell.com
- Created a patch to fix login and logout sounds in gnome-session
  Novell bug 294396 and bugzilla.gnome.org #466458
* Tue Sep  4 2007 maw@suse.de
- Update gnome-session-main-init.patch to use old-fashioned C
  style comments in lieu of C++ style comments, courtesy of Calvin
  (#302316 and bugzilla.gnome.org #469958).
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.90:
  + Updated translations.
* Tue Aug 28 2007 cgaisford@novell.com
- Further testing showed that the a11y needs to be done much lower
  in the loop so I've moved it down right before the gtk-main
* Mon Aug 27 2007 cgaisford@novell.com
- Added patch to move the a11y initialization lower in the startup
  so the session-manager has a chance to get started.
  Novell Bug #302316
* Fri Aug 24 2007 cgaisford@novell.com
- Changed logout UI to always show options but to disable them
  if they are not available.  Fix for Novell Bug 238299
- Included patch to fix up load time that is pending review
  upstream.  I'll add it to the spec file once approved
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Fri Aug  3 2007 dreveman@suse.de
- Update for compiz 0.5.2, which need glib plugin to be loaded
  before gconf plugin.
* Fri Aug  3 2007 cgaisford@suse.de
- Fixed up the tile-ui patch to work with the new gnome
* Thu Aug  2 2007 maw@suse.de
- Update to version 2.19.6:
  + Better fadeout animation for the logout dialogue when there is
    a compositing manager
  + Add gnome-breakpad to GTK_MODULES if bug-buddy is present
  + Use g_option_context_set_translation_domain()
  + Compilation fixes
  + Updated translations
* Thu Jul 19 2007 maw@suse.de
- Add gnome-session-no-devel-fatals.patch, courtesy of jpr (#292706
  and #292651)
- Some minor specfile cleanups, also courtesy of jpr.
* Tue Jul 10 2007 maw@suse.de
- Update to version 2.19.4
  ==============
  Version 2.19.4
  ==============
  Session Manager
  * Use g_timeout_add_seconds() when possible (Vincent)
  * Improve a bit "wrong clock" check when the user has reconfigured his
  clock (Vincent)
  * Fix crash when icons on the splash screen needs to be relayout-ed
  (Vincent)
  * Fix compilation issue on Solaris (Vincent)
  Session Properties Dialog
  * Fix a crash when the comment for a .desktop file is not defined and a
  startup program is disabled (Vincent)
  Misc
  * Require glib 2.13.0
  Translators
  * Tshewang Norbu (dz)
  ==============
  Version 2.19.3
  ==============
  Session Manager
  * Don't do logout fade if there's a compositing manager running
  (Ray Strode, Bastien Nocera)
  * Start accessibility if GNOME_ACCESSIBILITY is set (Wouter Bolsterlee,
  Vincent)
  Session Properties Dialog
  * Small code cleanup (Vincent)
  Translators
  * David Lodge (en_GB)
  * Jorge González (es)
  * Ivar Smolin (et)
  * Espen Stefansen (nb)
  * Daniel Nylander (sv)
  * Theppitak Karoonboonyanan (th)
  ===============
  Version 2.19.2
  ===============
  Session Manager
  * Use g_usleep() instead of usleep() (Bastien Nocera)
  * Don't hardcode start of assistive technologies software (Ariel Rios,
  Vincent)
  * Fix splash screen in RTL environments (Yair Hershkovitz)
  * Improve splash screen on old displays (Fedora patch)
  * Make it possible to use a shaped window for the splash screen
  (Fedora patch, Vincent)
  * Display the name of the started application in splash screen even if
  there's no icon (Vincent)
  * Don't use deprecated functions (Christian Persch, Vincent)
  * Don't hardcode esound for the sound daemon (Matthias Clasen, Vincent)
  * Make the fade on logout faster (Christof Krüger)
  * Plug leaks (Vincent)
  * Warn the user if he logs in as root (Vincent, Dan Winship)
  * Warn the user if the clock is totally wrong and let him launch a
  config tool (Vincent, Dan Winship)
  * Change strings about saving the session to be more user-friendly
  (Vincent)
  * Remove workaround that chrooted esd to / (fixed in esd) (Vincent)
  * Make it possible to save a session with multiple clients that are the
  same program (Hans de Goede, Dan Winship)
  * Use the new socket path for GDM (Loïc Minier)
  Session Properties Dialog
  * Use Add/Remove instead of New/Delete for handling startup programs
  (Luca Ferretti)
  * Show the comments in the startup programs list (Vincent)
  * Change strings about saving the session to be more user-friendly
  (Vincent)
  * Make it possible to sort the program lists by clicking on the headers
  (Vincent)
  * Create a non-localized version of the Comment field in .desktop files
  if necessary (Vincent)
  Misc
  * Remove xrdb check (Andreas Hanke)
  * Build fixes (Andreas Hanke, Christian Persch)
  * Require glib 2.12.0 (Vincent)
  * Add --with-time-utility configure flag to set the executable that is
  used to configure the time of the computer (Vincent)
  * Don't require libgnome-desktop anymore (Vincent)
  * Add support for beryl in gnome-wm (Alex)
  Translators
  * Peter Bach (da)
  * Jorge González (es)
  * Ivar Smolin (et)
  * Iñaki Larrañaga Murgoitio (eu)
  * Ignacio Casal Quinteiro (gl)
  * Yair Hershkovitz (he)
  * Espen Stefansen (nb)
  * Yannig MARCHEGAY (Kokoyaya) (oc)
  * Yang Zhang (zh_CN)
* Wed Apr  4 2007 sbrabec@suse.cz
- Session start script (gnome) cleanup (#254439).
* Tue Apr  3 2007 jhargadon@suse.de
- specfile cleanup (#255906)
* Mon Mar 19 2007 jpr@suse.de
- Update to 2.18.0
  * Drop legacy http_proxy support entirely since it is causing too
    many issues (Ray Strode)
  * Remove invalid category in .desktop file (Christian Kirbach)
  * Use the correct rate when a X resolution is configured
    (Jens Granseuer)
  * Don't exit when there's an unexpected dbus disconnection
    (Jan de Groot)
  * Translations
* Wed Mar 14 2007 sbrabec@suse.cz
- Fixed at-spi-registryd path (#254403).
* Fri Mar  9 2007 maw@suse.de
- Update to version 2.17.91.
  Session Properties Dialog
  * Update categories in the .desktop file for the new control center
    (Vincent)
  * Use new icon (Vincent)
  * Fix priority order of autostart desktop files with the same name
    (Vincent)
  * Report connection errors more gracefully (Tom Tromey)
  * Use GOption (Vincent)
  * Reuse existing desktop files instead of overwriting them (Vincent)
  * Rework code of edition of startup programs so that it actually works
    well and comply with the freedesktop spec (Vincent)
  * Use a toggle button to enable/disable startup programs (Vincent)
  * Add a "Save current session" button (Josselin Mouette)
  * Remove "ask to save" toggle button (Josselin Mouette)
  * Remove edition of session names (Vincent)
  * Remove splash screen toggle button (Vincent)
  * Change order of the tabs (Vincent)
  * Fix desktop file to use a correct icon (Vincent)
  * Improve default size of the dialog (Vincent)
  * Show names instead of commands for the startup programs (Vincent)
  * HIGify quit dialog (Michael Terry, Vincent)
  Session Manager
  * Warn the user about more fatal errors (Tom Tromey)
  * Use gtk-window-decorator for compiz (Vincent)
  * Fix crash when two at-spi-registryd are running (Li Yuan)
  * Don't hardcode start of assistive technologies software (Ariel Rios,
    Vincent)
  * Start the dbus daemon if it's not running (Julio M. Merino Vidal)
  * Kill esd on exit (Loïc Minier)
  * Fix priority order of autostart desktop files with the same name
    (Vincent)
  * Fix invalid use of memory (Tom Tromey)
  * Fix quoting of commands when migration to new autostart system
    (Tom Tromey)
  * Increase timeout for starting at-spi-registryd. This should prevent
    showing a window warning that accessibility won't work on slow
    machines. (Frédéric Crozat)
  * Hardcode start of assistive technologies software again since the
    control center won't be ready for this in 2.18 (Vincent)
  * Kill the clients in reverse order of priority, which makes logging
    out a better experience (metacity is killed last) (Tom Tromey)
  * Remove useless code (Claudio Saavedra)
  * Fix bug where clicking logout button doesn't work if
    mouse pointer happens to be on top of the button when
    the window is mapped (bug 52047) (Ray Strode)
  * Make treview searching search the right column
    (Brent Smith)
  * Get rid of init as the parent of all processes
    (Tom Tromey)
  * Add fading effect for the splash screen icons
    (Daniel Godás)
  * Add command line option to avoid confirmation dialog
    on kill (William McCann)
  * Add fvwm support (Ken Deeter)
  * Add support for compiz (Vincent)
  * Do less work if $WINDOW_MANAGER is set (Vincent)
  * Set http_proxy variable correctly (Ray Strode)
  * Don't set http_proxy variable at all if the proxy
    requires authentication (Ray Strode)
  * Don't pop up useless dialog when saving session (Tom Tromey)
  * Accept Enter key to close dialog when editing a session/startup
    program (Tom Tromey)
  * Set http_proxy environment variable based on GNOME settings
    for legacy apps (Ray Strode)
  * Launch at-spi-registryd for accessibility (Ariel Ros)
  * Improve gnome-session-remove command line handling (Tom Tromey)
  * Use Program instead of Command in the capplet (Tom Tromey)
* Fri Mar  2 2007 sbrabec@suse.cz
- Do not own /usr/share/xsessions (#229172).
* Mon Feb 12 2007 cgaisford@novell.com
- updated the UI from changes make in SLED.
* Sun Jan  7 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Dec 22 2006 federico@novell.com
- Removed the part of /usr/bin/gnome that overwrites the
  /desktop/gnome/font_rendering/dpi setting in GConf upon the user's
  first login.  With an updated control-center2 package,
  gnome-settings-daemon will take care of figuring out the right DPI
  value.  Fixes the gnome-session part of
  https://bugzilla.novell.com/show_bug.cgi?id=217790.
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches
- Update and re-enable gnome-session-remove-dns-warning.patch
* Fri Oct 13 2006 dreveman@suse.de
- Update compiz patch so it works with compiz 0.2.
* Wed Oct 11 2006 danw@suse.de
- Use a more explicit test for Xgl so that we don't try to run compiz
  under Xorg when compositing isn't enabled. #197093
- Remove some patches that were disabled with the 2.16 update that
  are definitely no longer relevant
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- Updated man pages from Debian
- translation updates
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- Updated splash screen
- translation updates
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.92
- Fix crash caused by debug output on Solaris
- translation updates
* Fri Aug 25 2006 stbinner@suse.de
- unbreak package by using new X.org 7.1 paths (#200466)
* Wed Aug 23 2006 jhargadon@suse.de
- update to version 2.15.91
- Fix leaks
- Use GOption
- Make it possible to really disable the login sound
- Set the right parent window for an error dialog
- Update keyring daemon DISPLAY environment variable if it's already
  running
- Fix sensitivity of edit/delete buttons when editing sessions
- Add support for e16 window manager in gnome-wm
- Fix edition of startup programs containing a space in a command line
  argument
- Add gnome-keyring dependency
* Tue Aug  1 2006 danw@suse.de
- If the session explicitly specifies metacity or compiz, but
  the "wrong" X server for that wm is running, switch back to
  gnome-wm. #180506
* Fri Jun 16 2006 danw@suse.de
- Pass --replace to compiz and gnome-window-decorator in case the
  copies run by gdm don't exit properly. #185296
* Mon Jun 12 2006 rodrigo@suse.de
- Added patch to create ~/.config/autostart before starting the
  migration from previous versions (#169509)
* Fri Jun  2 2006 gekker@suse.de
- Fix pager on upgrade (#181264)
* Wed May 31 2006 jpr@suse.de
- Don't run the migration script for new users (#179332)
* Wed May 24 2006 joeshaw@suse.de
- Fix the gnome script to not break when setting the background on
  multihead setups.  Patch from Erik Jacobsen.  (bnc #178388)
* Sun May 21 2006 jpr@suse.de
- Reset the user's UI if upgrading from NLD9/SLES9 to SLED10, leave ui
  for SLES10 upgrades (#174123)
* Sat May 13 2006 hpj@suse.de
- Update keyring unlockage patch to try both CASA's
  Gnome_Keyring_Default and Desktop passwords. Part of fix for
  Novell bug #174093.
* Tue May  9 2006 joeshaw@suse.de
- Fix a bash arithmetic typo introduced in the March 27 commit.
  (bnc #173808)
* Wed May  3 2006 danw@suse.de
- Update gnome-wm to pick metacity or compiz based on whether it's
  actually running under Xgl or not, regardless of what
  /etc/sysconfig/displaymanager says. Fixes Xnest logins. #170839.
* Tue May  2 2006 joeshaw@suse.de
- Don't write out a font using raw XML to the gconf database,
  that's wrong and evil.  Instead, try to set the desktop's DPI
  value using gconftool-2.  (bnc #171096)
* Fri Apr 28 2006 rodrigo@suse.de
- Save modified autostart files to user's home when they come from
  system-wide directories (170038).
* Wed Apr 26 2006 rodrigo@suse.de
- Don't free session_name, since it's needed at the end for saving
  the session correctly (169672).
* Thu Apr 13 2006 sbrabec@suse.cz
- Call %%suse_update_desktop_file.
- Use new control-center Categories instead of old ones.
* Fri Apr  7 2006 danw@suse.de
- Patch gnome-wm to prefer compiz when Xgl is running
* Wed Apr  5 2006 hpj@suse.de
- Fix keyring unlock patch to use g_strlcpy() correctly again.
  Fixes bug #159593 together with a CASA fix.
* Fri Mar 31 2006 rodrigo@suse.de
- Added missing "/" for /etc/xdg/autostart searching (#161322)
* Mon Mar 27 2006 jpr@suse.de
- Handle only shipping 2 sizes of backgrounds
* Tue Mar 21 2006 rodrigo@suse.de
- Added support for /etc/xdg/autostart directory, so that
  common services (zen-updater) can share it with GNOME/KDE.
* Wed Mar 15 2006 rodrigo@suse.de
- Added gnome-session-code-review.patch, resulting from the code
  review done by some members of the desktop team. It fixes a few
  leaks, avoids spawning unnecessary processes and makes use of
  a shared GConfClient for all the modules.
* Fri Mar 10 2006 jpr@suse.de
- Re-enable splash screen, point at the generically named splash in
  the gnome2-* packages so suse/sle[sd] branding is differentiated
* Thu Mar  9 2006 rodrigo@suse.de
- Removed gnome-session-default-applications.patch, all needed
  applications are now started, if installed, via the autostart
  mechanism.
* Mon Mar  6 2006 rodrigo@suse.de
- Fixed support for multiple system autostart directories.
- Disable GUI operations for system-wide files (#154755).
* Thu Mar  2 2006 rodrigo@suse.de
- Support GNOME 2.14 autostart directory also.
- Use g_strlcpy instead of strcpy when copying passwords.
* Wed Feb 22 2006 rodrigo@suse.de
- Added gnome-session-gsd-early-start.patch that fixes #150256.
* Thu Feb 16 2006 rodrigo@suse.de
- Don't try to remove non-existing files (#145870)
* Thu Feb 16 2006 rodrigo@suse.de
- Updated gnome-session-suspend-patch to make suspend work as
  expected (#117491)
* Wed Feb 15 2006 rodrigo@suse.de
- Added MOTD on login, as requested by customer.
* Mon Feb 13 2006 hpj@suse.de
- Added patch to support KDM's logout options.
* Fri Feb 10 2006 joeshaw@suse.de
- Remove the beagled invocation from the /usr/X11R6/bin/gnome
  shell script; it gets invoked through the new autostart
  mechanism now.  (bnc #150041)
* Thu Feb  9 2006 rodrigo@suse.de
- Updated gnome-session-suspend.patch to not exit the X session
  when suspend is selected on the logout dialog (117491)
* Wed Feb  8 2006 joeshaw@suse.de
- Add an "--indexing-delay 300" option when starting beagled.
  This will reduce disk thrash at login time by waiting 5 minutes
  before it starts to index.
* Wed Feb  8 2006 aj@suse.de
- No need to link against micasa anymore.
- Reduce BuildRequires.
* Mon Feb  6 2006 hpj@suse.de
- Fixed gnome-keyring-unlock patch to give correct soname for
  casa.
* Mon Feb  6 2006 hpj@suse.de
- Updated gnome-keyring-unlock patch with dlopen hack from CASA
  team. I have no idea why this is required.
* Mon Feb  6 2006 ro@suse.de
- make it build on x86_64 (adding libdir to CASA unlock patch)
* Fri Feb  3 2006 rodrigo@suse.de
- Added gnome-session-rdesktop.diff, that fixes hang on login when
  a11y enabled (147985)
* Wed Feb  1 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Wed Feb  1 2006 rodrigo@suse.de
- Remove duplicated processes by comparing the program name, not
  the whole command line.
* Sat Jan 28 2006 hpj@suse.de
- Added patch to unlock default GNOME keyring using the CASA
  password, optionally creating it if it doesn't exist.
* Fri Jan 27 2006 hpj@suse.de
- Set the ICEAUTHORITY env var so programs running as root can
  get to the cookies. Eliminates hangs on logout.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 rodrigo@suse.de
- Updated autostart patch with a simple fix for a crash found when
  starting the session.
- Fixed build by depending on dbus-1-*
* Mon Jan 16 2006 rodrigo@suse.de
- Fixed ia64 build by depending on hal/hal-devel.
* Mon Jan 16 2006 rodrigo@suse.de
- Updated autostart patch to include user's ability to disable
  autostarted programs.
* Thu Jan 12 2006 rodrigo@suse.de
- Added upstream patch for #105789.
* Wed Jan 11 2006 jpr@suse.de
- Remove hardcoded susewatcher (130893)
* Tue Jan 10 2006 rodrigo@suse.de
- Updated autostart patch that includes code to migrate from the
  old ~/.gnome2/session-manual to the .desktop file-based thing
  in the user's home directory.
* Sat Jan  7 2006 dreveman@suse.de
- Improved logout effect patch
* Thu Jan  5 2006 rodrigo@suse.de
- Small fix to previous patch to avoid crash.
* Thu Jan  5 2006 rodrigo@suse.de
- Updated autostart patch to include usage of .config/autostart for
  user-specified autostarted programs in sessions capplet.
* Wed Jan  4 2006 dreveman@suse.de
- Add patch with support for compositing manager logout effects
* Tue Dec 13 2005 rodrigo@suse.de
- Fixed user's autostart directory.
* Fri Dec  9 2005 rodrigo@suse.de
- Don't autostart beagle, it's now started via the autostart thing.
* Wed Dec  7 2005 rodrigo@suse.de
- Don't autostart resapplet, it now includes its .desktop file
  in the autostart directory.
* Tue Nov 22 2005 rodrigo@suse.de
- Don't start nm-applet and netapplet, now started via the autostart
  thing.
* Wed Nov 16 2005 jpr@suse.de
- Use "default" links for wallpaper
- Don't hard code background color during startup
- Turn off splash screen by default
* Mon Nov 14 2005 rodrigo@suse.de
- Updated autostart patch to support per user's autostart directory
  and to remove duplicated entries (based on command line).
* Thu Nov 10 2005 rodrigo@suse.de
- Added support for X-GNOME-Autostart-enabled field in autostart
  .desktop files.
* Wed Nov  9 2005 rodrigo@suse.de
- Added autostart implementation patch.
- Removed execution of gnome-power/volume-manager, now started
  via the autostart thing.
* Wed Nov  2 2005 sreeves@suse.de
- add gnome-session-login-sounds.patch to fix the default system
  sound playing when the user has selected no sound.
* Wed Oct 26 2005 rml@suse.de
- Add "--sm-disable" to nm-applet spawning.  No point in using
  session management if we are going to start the thing manually.
  Fix requested by Joey "Buckeye" Shaw.
* Mon Oct 17 2005 rodrigo@suse.de
- Start gnome-power-manager also.
* Tue Oct  4 2005 rodrigo@suse.de
- Don't launch gnome-session via dbus-launch.
* Mon Sep 12 2005 aj@suse.de
- Use SUSE Linux 10.0 background [#102355].
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 2.12.0.
* Mon Aug 29 2005 jpr@suse.de
- Remove hacky workaround for 104161 (fixed upstream in gtk 2.8.2)
- Update branding (102355)
* Mon Aug 22 2005 gekker@suse.de
- Update path to autostart NetworkManager applet in new location
* Fri Aug 19 2005 jpr@suse.de
- Update to blue splash screen coloring
* Wed Aug 17 2005 clahey@suse.de
- Improve performance of logout fading.
* Fri Aug 12 2005 gekker@suse.de
- Add --autostarted to beagled and best (102606)
- Autostart nm-applet if it is installed
- Remove suseplugger, no longer needed
- Workaround crash in netapplet and best on startup
* Thu Aug 11 2005 jpr@suse.de
- Update splash for 10.0
* Tue Aug  9 2005 rodrigo@suse.de
- Update to 2.11.91, which includes fix for #102652
* Fri Aug  5 2005 gekker@suse.de
- Start gnome-volume-manager with session
* Thu Aug  4 2005 gekker@suse.de
- Start beagle by default, disable with ~/.dontrunbeagle
* Tue Aug  2 2005 gekker@suse.de
- Update to 2.11.90
* Mon Aug  1 2005 rodrigo@suse.de
- Use --exit-with-session when running dbus-launch, to avoid leaving
  running processes after terminating the session.
* Fri Jul 22 2005 rodrigo@suse.de
- Start gnome-session with dbus-launch, to get the notification
  daemon working for new gnome-applets
- Depend on dbus-1-x11, for dbus-launch
* Thu Jun 23 2005 gekker@suse.de
- Update to version 2.11.1
* Thu May  5 2005 gekker@suse.de
- Launch iprint-gnome-init by default
* Mon Mar 21 2005 gekker@suse.de
- Don't run beagle unless ~/.runbeagle exists (#74029)
* Sat Mar 19 2005 jody@suse.de
- Enable suspend if it is available. (#73000)
* Thu Mar 17 2005 clahey@suse.de
- Patch fixes freeze on login.
* Wed Mar 16 2005 sbrabec@suse.cz
- Fixed gnome-session-desktop-file.patch (#73047).
* Mon Mar 14 2005 clahey@suse.de
- Update gnome splash from artists.
* Thu Mar 10 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Mon Mar  7 2005 gekker@suse.de
- mv suseplugger to default-apps patch
- launch netapplet, resapplet, and best on startup
* Fri Feb 25 2005 gekker@suse.de
- Add launch wrapper to launch beagled if installed in file gnome
* Wed Feb  9 2005 sbrabec@suse.cz
- Added session desktop file.
* Tue Dec 21 2004 gekker@suse.de
- Update to version 2.9.2
- Remove remove-purge-timeout patch, already upstream
- Reworked a couple patches
- Changed no -> nb to be like most other gnome modules
* Thu Oct 21 2004 ro@suse.de
- locale rename: no -> nb
* Wed Oct  6 2004 hhetter@suse.de
- call gconftool-2 instead of gconftool, don't trigger
  gconfd-1 on first startup with preconfiguration (#46917)
* Mon Sep 27 2004 hhetter@suse.de
- also start susewatcher (#46161)
* Sat Sep 25 2004 hhetter@suse.de
- use a cascaded KDE configuration in GNOME, allows to make
  things like suseplugger better suited for GNOME (part of #45420)
* Tue Sep 21 2004 hhetter@suse.de
- force new 9.2 wallpapers when updating from 9.1
* Mon Sep 20 2004 hhetter@suse.de
- adapt gnome session script for the new wallpapers
* Fri Sep 17 2004 hhetter@suse.de
- use gconftool to set background in the pre session script
- fix picture_scale string (partly #45418 )
* Fri Sep 10 2004 ro@suse.de
- added shared-mime-info to neededforbuild
* Fri Sep 10 2004 hhetter@suse.de
- run use_default_session again to make the 9.2 distribution
  wallpapers accessible
* Thu Sep  9 2004 federico@ximian.com
- Added gnome-session-remove-purge-timeout.diff, to fix
  http://bugzilla.gnome.org/show_bug.cgi?id=151664
- Changed gnome-session-suseplugger.patch to run suseplugger with
  better options.
* Mon Aug 30 2004 hhetter@suse.de
- remove gnome-session-branding.patch, use the original
  gnome 2.6 splash (for now)
* Wed Aug 25 2004 shprasad@suse.de
- Fixes bug #63860
  Fixes gnome-session crash at logout.
* Fri Aug 20 2004 shprasad@suse.de
- Fixes bug #61567
  kdm shows 'Reboot' and 'Shutdown' options at the time
  of logout.
* Thu Aug  5 2004 clahey@suse.de
- Added gnome-session-remove-dns-warning.patch from Federico.
* Fri Jul 16 2004 shprasad@suse.de
- Fixes bug #59918
  Hides the splash-screen once the difault setting gets loaded.
* Thu Jul  8 2004 sbrabec@suse.cz
- Added DESKTOP_LAUNCH patch from Jan Holesovsky.
* Fri Jun 18 2004 dave@suse.de
- Don't set the wallpaper or font in the gnome startup script.
* Fri Jun 11 2004 clahey@suse.de
- Added gnome-session-use-gdmctl.patch.
* Thu Jun  3 2004 clahey@suse.de
- Switch to Novell session splash screen.
* Wed Jun  2 2004 mibarra@suse.de
- Make GNOME use suseplugger
* Tue May 11 2004 clahey@suse.de
- Added gnome-session-2.0.5-dithering.patch to use MAX dithering.
- Added gnome-session-desktop-file.patch to make gnome-session show
  up in control-center.
* Mon Apr 26 2004 sbrabec@suse.cz
- Updated to version 2.6.1 (GNOME 2.6).
* Tue Apr  6 2004 hhetter@suse.de
- fix incomplete usage of YAST_DIR (#38374), to get visible
  YaST Icons
* Thu Apr  1 2004 hhetter@suse.de
- change YAST_DIR for GNOME_ICON_PATH to reflect it's new
  location in ./theme/current/icons/
* Wed Mar 24 2004 hhetter@suse.de
- extend arbitrary icon path with some more crystalsvg locations
* Mon Mar 22 2004 hhetter@suse.de
- added arbitrary icon path to gnome session
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Thu Mar 11 2004 sbrabec@suse.cz
- Export STYLE variable in GNOME session, as startkde does.
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed %%doc attributes (#33163).
* Fri Mar  5 2004 hhetter@suse.de
- use new wallpaper path (now using desktop-data-SuSE) and
  filenames
* Mon Feb 23 2004 sbrabec@suse.cz
- Removed incorrect initialization of LD_LIBRARY_PATH (bug #34777).
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Thu Feb  5 2004 hhetter@suse.de
- updated to version 2.4.2 [GNOME2.4.2]
* Sat Jan 10 2004 adrian@suse.de
- fix build as user
* Thu Nov  6 2003 hhetter@suse.de
- no longer create .gnome-desktop
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.1.
* Tue Oct  7 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Mon Sep 22 2003 hhetter@suse.de
- obsolete gnome-core (Bug Id # 31480)
- remove intro script from default session (Bug Id#29807)
* Fri Sep  5 2003 sbrabec@suse.cz
- gnome: Prevent GTK1 theme overlay (bug 25645, comment #36).
* Fri Sep  5 2003 hhetter@suse.de
- add support for preconfigured gnome1 settings
* Tue Aug  5 2003 sbrabec@suse.cz
- Session start script gnome: don't use GNOMEPATH, updated GTK_RC_FILES.
* Tue Jul 15 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Updated neededforbuild.
- Use %%find_lang.
- Added support for tcpd.
- Require control-center2.
- Removed distribution desktop files.
* Wed May 28 2003 sbrabec@suse.cz
- Compress manpages.
* Tue May 27 2003 ro@suse.de
- added manpages to filelist
* Tue Mar 18 2003 sbrabec@suse.cz
- Variables already set in profile files removed from session startup
  file (consequence of bugfixes #25086, #25170, #25575).
- Manage GTK1 themes with gnome-theme-manager (set GTK_RC_FILES).
* Mon Mar 17 2003 sbrabec@suse.cz
- Removed /opt/gnome2 from GNOME2_PATH (fixes #24601).
* Mon Mar  3 2003 hhetter@suse.de
- remove documents directories (Bug Id#24589)
- add search path for KDE icons (Bug Id#24590)
* Mon Feb 24 2003 hhetter@suse.de
- mention feedback website in session script
  instead of feedback@suse.de
* Thu Feb 20 2003 hhetter@suse.de
- set G_BROKEN_FILENAMES=1 to handle invalid UTF8
  filenames as local-specific
* Tue Feb 18 2003 hhetter@suse.de
- fill solid color at first time
* Fri Feb 14 2003 hhetter@suse.de
- use GTK_DATA_PREFIX while in GNOME Session
* Thu Feb 13 2003 hhetter@suse.de
- set GNOME2_PATH in session
* Tue Feb 11 2003 hhetter@suse.de
- fix documents-file creation
* Mon Feb 10 2003 hhetter@suse.de
- updated to version 2.2.0.2 [GNOME 2.2.0]
- removed Intro script (moving to preconfiguration package)
- allow for different splash image via preconfiguration package
* Tue Jan 28 2003 hhetter@suse.de
- updated to version 2.2.0.1
- some SLOD feature backports
  (file type desktop links, Intro script)
* Thu Jan 16 2003 sbrabec@suse.cz
- Added libjpeg to neededforbuild.
* Thu Nov 28 2002 hhetter@suse.de
- updated to version 2.0.9 [GNOME 2.0.3]
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Wed Nov  6 2002 hhetter@suse.de
- use correct kde-datadir
- no longer create .gnome for gnome-vfs2
- look for addon scripts to run on first start
* Tue Oct 22 2002 hhetter@suse.de
- updated to version 2.0.10
- removed wrong docdir
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Tue Sep 17 2002 hhetter@suse.de
- added correct hu translations
* Mon Sep  2 2002 hhetter@suse.de
- set background to gray until splash becomes visible
  (reviewed by Ken)
* Thu Aug 29 2002 hhetter@suse.de
- rename gnome2 to gnome, to keep the GNOME session for
  users who are updating the distribution (Bug Id#18552)
* Thu Aug 22 2002 hhetter@suse.de
- use jpg as wallpaper format for preconfiguration
* Tue Aug 20 2002 hhetter@suse.de
- added PreReq: filesystem
* Tue Aug 13 2002 hhetter@suse.de
- remove control-center deps from neededforbuild
* Thu Aug  8 2002 hhetter@suse.de
- updated to version 2.0.5, bug id's relate to bugzilla.gnome.org
  * Fix crashing when starting emacs, #89968
* Mon Aug  5 2002 hhetter@suse.de
- updated to version 2.0.4
  * amend global save to Both if user selects save session
  * capplet saving state fix
  * translation updates
* Thu Aug  1 2002 hhetter@suse.de
- include the session startup script
* Tue Jul 30 2002 hhetter@suse.de
- updated to version 2.0.3
  session-manager:
  * Re-write the splash screen to not use the canvas
  * Fix crash with logout dialog
  * Make file selector when editing startup programs modal
  * Increased initial client timeout to 30 seconds
  Translation updates
* Tue Jul 23 2002 hhetter@suse.de
- updated to version 2.0.2
* Thu Jun 20 2002 hhetter@suse.de
- updated to version 2.0.1
- don't install schemas while make install
* Sun Jun 16 2002 ro@suse.de
- use libpng-devel-packages in neededforbuild
* Fri Jun 14 2002 hhetter@suse.de
- provide schema file
- filelist rework
* Tue Jun 11 2002 hhetter@suse.de
- updated to version 2.0.0
* Tue Jun  4 2002 hhetter@suse.de
- updated to version 1.5.21, source frozen
* Mon Apr 15 2002 hhetter@suse.de
- initial SuSE Release
